summaryrefslogtreecommitdiffstats
path: root/desktop
diff options
context:
space:
mode:
authorNoel Grandin <noel@peralex.com>2015-09-11 14:40:54 +0200
committerCaolán McNamara <caolanm@redhat.com>2015-09-12 19:53:18 +0000
commit4a9b401f9877b348a0e716e79cb8cc41645ceba3 (patch)
treeecddc4e20b644d12e3c83589be2c5692f827e7f0 /desktop
parenttdf#92794: '$' should be replaced in error dialog of addressbook (diff)
downloadcore-4a9b401f9877b348a0e716e79cb8cc41645ceba3.tar.gz
core-4a9b401f9877b348a0e716e79cb8cc41645ceba3.zip
desktop: com::sun::star->css
Change-Id: Ie94dea9b4f48829132ceadcbf36634eeed191bb9 Reviewed-on: https://gerrit.libreoffice.org/18498 Tested-by: Jenkins <ci@libreoffice.org> Reviewed-by: Caolán McNamara <caolanm@redhat.com> Tested-by: Caolán McNamara <caolanm@redhat.com>
Diffstat (limited to 'desktop')
-rw-r--r--desktop/source/app/app.cxx100
-rw-r--r--desktop/source/app/appinit.cxx2
-rw-r--r--desktop/source/app/check_ext_deps.cxx2
-rw-r--r--desktop/source/app/cmdlineargs.cxx2
-rw-r--r--desktop/source/app/desktopcontext.hxx10
-rw-r--r--desktop/source/app/dispatchwatcher.cxx16
-rw-r--r--desktop/source/app/dispatchwatcher.hxx8
-rw-r--r--desktop/source/app/langselect.cxx2
-rw-r--r--desktop/source/app/officeipcthread.hxx24
-rw-r--r--desktop/source/app/sofficemain.cxx2
-rw-r--r--desktop/source/deployment/gui/dp_gui.h4
-rw-r--r--desktop/source/deployment/gui/dp_gui_dialog2.hxx60
-rw-r--r--desktop/source/deployment/gui/dp_gui_extensioncmdqueue.hxx18
-rw-r--r--desktop/source/deployment/gui/dp_gui_extlistbox.hxx22
-rw-r--r--desktop/source/deployment/gui/dp_gui_theextmgr.hxx48
-rw-r--r--desktop/source/deployment/gui/dp_gui_updatedata.hxx8
-rw-r--r--desktop/source/deployment/gui/dp_gui_updatedialog.cxx14
-rw-r--r--desktop/source/deployment/gui/dp_gui_updatedialog.hxx21
-rw-r--r--desktop/source/deployment/gui/dp_gui_updateinstalldialog.hxx8
-rw-r--r--desktop/source/deployment/inc/dp_dependencies.hxx6
-rw-r--r--desktop/source/deployment/inc/dp_descriptioninfoset.hxx41
-rw-r--r--desktop/source/deployment/inc/dp_identifier.hxx4
-rw-r--r--desktop/source/deployment/inc/dp_misc.h16
-rw-r--r--desktop/source/deployment/inc/dp_platform.hxx2
-rw-r--r--desktop/source/deployment/inc/dp_update.hxx30
-rw-r--r--desktop/source/deployment/manager/dp_activepackages.hxx2
-rw-r--r--desktop/source/deployment/manager/dp_manager.cxx2
-rw-r--r--desktop/source/deployment/manager/dp_manager.h2
-rw-r--r--desktop/source/deployment/misc/dp_descriptioninfoset.cxx10
-rw-r--r--desktop/source/deployment/registry/configuration/dp_configuration.cxx6
-rw-r--r--desktop/source/migration/migration.cxx2
-rw-r--r--desktop/source/migration/services/basicmigration.hxx32
-rw-r--r--desktop/source/migration/services/jvmfwk.cxx52
-rw-r--r--desktop/source/migration/services/oo3extensionmigration.hxx78
-rw-r--r--desktop/source/migration/services/wordbookmigration.hxx32
-rw-r--r--desktop/source/offacc/acceptor.hxx2
-rw-r--r--desktop/source/pkgchk/unopkg/unopkg_app.cxx4
-rw-r--r--desktop/source/splash/splash.cxx4
-rw-r--r--desktop/source/splash/splash.hxx8
-rw-r--r--desktop/source/splash/unxsplash.cxx2
-rw-r--r--desktop/source/splash/unxsplash.hxx2
-rw-r--r--desktop/test/deployment/update/updateinfocreation/build/TestExtension.idl2
42 files changed, 349 insertions, 363 deletions
diff --git a/desktop/source/app/app.cxx b/desktop/source/app/app.cxx
index 14a9a21c64c7..153196386567 100644
--- a/desktop/source/app/app.cxx
+++ b/desktop/source/app/app.cxx
@@ -1275,8 +1275,7 @@ int Desktop::Main()
pExecGlobals = new ExecuteGlobals();
// Remember current context object
- com::sun::star::uno::ContextLayer layer(
- com::sun::star::uno::getCurrentContext() );
+ css::uno::ContextLayer layer( css::uno::getCurrentContext() );
if ( m_aBootstrapError != BE_OK )
{
@@ -1290,8 +1289,7 @@ int Desktop::Main()
}
// Detect desktop environment - need to do this as early as possible
- com::sun::star::uno::setCurrentContext(
- new DesktopContext( com::sun::star::uno::getCurrentContext() ) );
+ css::uno::setCurrentContext( new DesktopContext( css::uno::getCurrentContext() ) );
CommandLineArgs& rCmdLineArgs = GetCommandLineArgs();
@@ -1500,13 +1498,13 @@ int Desktop::Main()
}
}
}
- catch ( const com::sun::star::lang::WrappedTargetException& wte )
+ catch ( const css::lang::WrappedTargetException& wte )
{
- com::sun::star::uno::Exception te;
+ css::uno::Exception te;
wte.TargetException >>= te;
FatalError( MakeStartupConfigAccessErrorMessage(wte.Message + te.Message) );
}
- catch ( const com::sun::star::uno::Exception& e )
+ catch ( const css::uno::Exception& e )
{
FatalError( MakeStartupErrorMessage(e.Message) );
}
@@ -1549,7 +1547,7 @@ int Desktop::Main()
xDesktop->addTerminateListener( new OfficeIPCThreadController );
SetSplashScreenProgress(100);
}
- catch ( const com::sun::star::uno::Exception& e )
+ catch ( const css::uno::Exception& e )
{
FatalError( MakeStartupErrorMessage(e.Message) );
}
@@ -1575,8 +1573,8 @@ int Desktop::Main()
#if HAVE_FEATURE_JAVA
// The JavaContext contains an interaction handler which is used when
// the creation of a Java Virtual Machine fails
- com::sun::star::uno::ContextLayer layer2(
- new svt::JavaContext( com::sun::star::uno::getCurrentContext() ) );
+ css::uno::ContextLayer layer2(
+ new svt::JavaContext( css::uno::getCurrentContext() ) );
#endif
// check whether the shutdown is caused by restart just before entering the Execute
pExecGlobals->bRestartRequested = pExecGlobals->bRestartRequested ||
@@ -1590,17 +1588,17 @@ int Desktop::Main()
Execute();
}
}
- catch(const com::sun::star::document::CorruptedFilterConfigurationException& exFilterCfg)
+ catch(const css::document::CorruptedFilterConfigurationException& exFilterCfg)
{
OfficeIPCThread::SetDowning();
FatalError( MakeStartupErrorMessage(exFilterCfg.Message) );
}
- catch(const com::sun::star::configuration::CorruptedConfigurationException& exAnyCfg)
+ catch(const css::configuration::CorruptedConfigurationException& exAnyCfg)
{
OfficeIPCThread::SetDowning();
FatalError( MakeStartupErrorMessage(exAnyCfg.Message) );
}
- catch( const ::com::sun::star::uno::Exception& exUNO)
+ catch( const css::uno::Exception& exUNO)
{
OfficeIPCThread::SetDowning();
FatalError( exUNO.Message);
@@ -1712,24 +1710,24 @@ bool Desktop::InitializeConfiguration()
comphelper::getProcessComponentContext() );
return true;
}
- catch( ::com::sun::star::lang::ServiceNotRegisteredException & e )
+ catch( css::lang::ServiceNotRegisteredException & e )
{
HandleBootstrapErrors(
Desktop::BE_UNO_SERVICE_CONFIG_MISSING, e.Message );
}
- catch( const ::com::sun::star::configuration::MissingBootstrapFileException& e )
+ catch( const css::configuration::MissingBootstrapFileException& e )
{
OUString aMsg( CreateErrorMsgString( utl::Bootstrap::MISSING_BOOTSTRAP_FILE,
e.BootstrapFileURL ));
HandleBootstrapPathErrors( ::utl::Bootstrap::INVALID_USER_INSTALL, aMsg );
}
- catch( const ::com::sun::star::configuration::InvalidBootstrapFileException& e )
+ catch( const css::configuration::InvalidBootstrapFileException& e )
{
OUString aMsg( CreateErrorMsgString( utl::Bootstrap::INVALID_BOOTSTRAP_FILE_ENTRY,
e.BootstrapFileURL ));
HandleBootstrapPathErrors( ::utl::Bootstrap::INVALID_BASE_INSTALL, aMsg );
}
- catch( const ::com::sun::star::configuration::InstallationIncompleteException& )
+ catch( const css::configuration::InstallationIncompleteException& )
{
OUString aVersionFileURL;
OUString aMsg;
@@ -1741,27 +1739,27 @@ bool Desktop::InitializeConfiguration()
HandleBootstrapPathErrors( ::utl::Bootstrap::MISSING_USER_INSTALL, aMsg );
}
- catch ( const com::sun::star::configuration::backend::BackendAccessException& exception)
+ catch ( const css::configuration::backend::BackendAccessException& exception)
{
// [cm122549] It is assumed in this case that the message
// coming from InitConfiguration (in fact CreateApplicationConf...)
// is suitable for display directly.
FatalError( MakeStartupErrorMessage( exception.Message ) );
}
- catch ( const com::sun::star::configuration::backend::BackendSetupException& exception)
+ catch ( const css::configuration::backend::BackendSetupException& exception)
{
// [cm122549] It is assumed in this case that the message
// coming from InitConfiguration (in fact CreateApplicationConf...)
// is suitable for display directly.
FatalError( MakeStartupErrorMessage( exception.Message ) );
}
- catch ( const ::com::sun::star::configuration::CannotLoadConfigurationException& )
+ catch ( const css::configuration::CannotLoadConfigurationException& )
{
OUString aMsg( CreateErrorMsgString( utl::Bootstrap::INVALID_BOOTSTRAP_DATA,
OUString() ));
HandleBootstrapPathErrors( ::utl::Bootstrap::INVALID_BASE_INSTALL, aMsg );
}
- catch( const ::com::sun::star::uno::Exception& )
+ catch( const css::uno::Exception& )
{
OUString aMsg( CreateErrorMsgString( utl::Bootstrap::INVALID_BOOTSTRAP_DATA,
OUString() ));
@@ -1807,7 +1805,7 @@ bool Desktop::InitializeQuickstartMode( const Reference< XComponentContext >& rx
}
return true;
}
- catch( const ::com::sun::star::uno::Exception& )
+ catch( const css::uno::Exception& )
{
return false;
}
@@ -1888,7 +1886,7 @@ IMPL_LINK_NOARG_TYPED(Desktop, OpenClients_Impl, void*, void)
const char *pExitPostStartup = getenv ("OOO_EXIT_POST_STARTUP");
if (pExitPostStartup && *pExitPostStartup)
new ExitTimer();
- } catch (const ::com::sun::star::uno::Exception &e) {
+ } catch (const css::uno::Exception &e) {
OUString a( "UNO exception during client open:\n" );
Application::Abort( a + e.Message );
}
@@ -1903,7 +1901,7 @@ IMPL_STATIC_LINK_NOARG_TYPED(Desktop, EnableAcceptors_Impl, void*, void)
void Desktop::PreloadModuleData( const CommandLineArgs& rArgs )
{
- Sequence < com::sun::star::beans::PropertyValue > args(1);
+ Sequence < css::beans::PropertyValue > args(1);
args[0].Name = "Hidden";
args[0].Value <<= sal_True;
Reference < XDesktop2 > xDesktop = css::frame::Desktop::create( ::comphelper::getProcessComponentContext() );
@@ -1912,11 +1910,11 @@ void Desktop::PreloadModuleData( const CommandLineArgs& rArgs )
{
try
{
- Reference < ::com::sun::star::util::XCloseable > xDoc( xDesktop->loadComponentFromURL( OUString("private:factory/swriter"),
+ Reference < css::util::XCloseable > xDoc( xDesktop->loadComponentFromURL( OUString("private:factory/swriter"),
OUString("_blank"), 0, args ), UNO_QUERY_THROW );
xDoc->close( sal_False );
}
- catch ( const com::sun::star::uno::Exception& )
+ catch ( const css::uno::Exception& )
{
}
}
@@ -1924,11 +1922,11 @@ void Desktop::PreloadModuleData( const CommandLineArgs& rArgs )
{
try
{
- Reference < ::com::sun::star::util::XCloseable > xDoc( xDesktop->loadComponentFromURL( OUString("private:factory/scalc"),
+ Reference < css::util::XCloseable > xDoc( xDesktop->loadComponentFromURL( OUString("private:factory/scalc"),
OUString("_blank"), 0, args ), UNO_QUERY_THROW );
xDoc->close( sal_False );
}
- catch ( const com::sun::star::uno::Exception& )
+ catch ( const css::uno::Exception& )
{
}
}
@@ -1936,11 +1934,11 @@ void Desktop::PreloadModuleData( const CommandLineArgs& rArgs )
{
try
{
- Reference < ::com::sun::star::util::XCloseable > xDoc( xDesktop->loadComponentFromURL( OUString("private:factory/sdraw"),
+ Reference < css::util::XCloseable > xDoc( xDesktop->loadComponentFromURL( OUString("private:factory/sdraw"),
OUString("_blank"), 0, args ), UNO_QUERY_THROW );
xDoc->close( sal_False );
}
- catch ( const com::sun::star::uno::Exception& )
+ catch ( const css::uno::Exception& )
{
}
}
@@ -1948,11 +1946,11 @@ void Desktop::PreloadModuleData( const CommandLineArgs& rArgs )
{
try
{
- Reference < ::com::sun::star::util::XCloseable > xDoc( xDesktop->loadComponentFromURL( OUString("private:factory/simpress"),
+ Reference < css::util::XCloseable > xDoc( xDesktop->loadComponentFromURL( OUString("private:factory/simpress"),
OUString("_blank"), 0, args ), UNO_QUERY_THROW );
xDoc->close( sal_False );
}
- catch ( const com::sun::star::uno::Exception& )
+ catch ( const css::uno::Exception& )
{
}
}
@@ -1982,7 +1980,7 @@ void Desktop::PreloadConfigurationData()
xCmdAccess->getByName(".uno:EditGlossary");
}
}
- catch ( const ::com::sun::star::uno::Exception& )
+ catch ( const css::uno::Exception& )
{
}
@@ -1993,7 +1991,7 @@ void Desktop::PreloadConfigurationData()
if ( xCmdAccess.is() )
xCmdAccess->getByName(".uno:InsertObjectStarMath");
}
- catch ( const ::com::sun::star::uno::Exception& )
+ catch ( const css::uno::Exception& )
{
}
@@ -2005,7 +2003,7 @@ void Desktop::PreloadConfigurationData()
if ( xCmdAccess.is() )
xCmdAccess->getByName(".uno:Polygon");
}
- catch ( const ::com::sun::star::uno::Exception& )
+ catch ( const css::uno::Exception& )
{
}
@@ -2019,7 +2017,7 @@ void Desktop::PreloadConfigurationData()
if ( xWindowAccess.is() )
xWindowAccess->getByName("private:resource/toolbar/standardbar");
}
- catch ( const ::com::sun::star::uno::Exception& )
+ catch ( const css::uno::Exception& )
{
}
try
@@ -2029,7 +2027,7 @@ void Desktop::PreloadConfigurationData()
if ( xWindowAccess.is() )
xWindowAccess->getByName("private:resource/toolbar/standardbar");
}
- catch ( const ::com::sun::star::uno::Exception& )
+ catch ( const css::uno::Exception& )
{
}
try
@@ -2039,7 +2037,7 @@ void Desktop::PreloadConfigurationData()
if ( xWindowAccess.is() )
xWindowAccess->getByName("private:resource/toolbar/standardbar");
}
- catch ( const ::com::sun::star::uno::Exception& )
+ catch ( const css::uno::Exception& )
{
}
try
@@ -2049,7 +2047,7 @@ void Desktop::PreloadConfigurationData()
if ( xWindowAccess.is() )
xWindowAccess->getByName("private:resource/toolbar/standardbar");
}
- catch ( const ::com::sun::star::uno::Exception& )
+ catch ( const css::uno::Exception& )
{
}
@@ -2059,7 +2057,7 @@ void Desktop::PreloadConfigurationData()
{
xUIElementFactory->getRegisteredFactories();
}
- catch ( const ::com::sun::star::uno::Exception& )
+ catch ( const css::uno::Exception& )
{
}
@@ -2074,7 +2072,7 @@ void Desktop::PreloadConfigurationData()
OUString( ".uno:CharFontName" ),
OUString() );
}
- catch ( const ::com::sun::star::uno::Exception& )
+ catch ( const css::uno::Exception& )
{
}
@@ -2088,7 +2086,7 @@ void Desktop::PreloadConfigurationData()
{
xNameAccess->getElementNames();
}
- catch ( const ::com::sun::star::uno::Exception& )
+ catch ( const css::uno::Exception& )
{
}
}
@@ -2103,7 +2101,7 @@ void Desktop::PreloadConfigurationData()
{
xNameAccess->getElementNames();
}
- catch ( const ::com::sun::star::uno::Exception& )
+ catch ( const css::uno::Exception& )
{
}
}
@@ -2260,7 +2258,7 @@ void Desktop::OpenClients()
xSessionListener = SessionListener::createWithOnQuitFlag(
::comphelper::getProcessComponentContext(), isUIOnSessionShutdownAllowed());
}
- catch(const com::sun::star::uno::Exception& e)
+ catch(const css::uno::Exception& e)
{
SAL_WARN( "desktop.app", "Registration of session listener failed" << e.Message);
}
@@ -2272,7 +2270,7 @@ void Desktop::OpenClients()
{
xSessionListener->doRestore();
}
- catch(const com::sun::star::uno::Exception& e)
+ catch(const css::uno::Exception& e)
{
SAL_WARN( "desktop.app", "Error in session management" << e.Message);
}
@@ -2485,27 +2483,27 @@ void Desktop::HandleAppEvent( const ApplicationEvent& rAppEvent )
if ( !xTask.is() )
{
// get any task if there is no active one
- Reference< css::container::XIndexAccess > xList( xDesktop->getFrames(), ::com::sun::star::uno::UNO_QUERY );
+ Reference< css::container::XIndexAccess > xList( xDesktop->getFrames(), css::uno::UNO_QUERY );
if ( xList->getCount() > 0 )
xList->getByIndex(0) >>= xTask;
}
if ( xTask.is() )
{
- Reference< com::sun::star::awt::XTopWindow > xTop( xTask->getContainerWindow(), UNO_QUERY );
+ Reference< css::awt::XTopWindow > xTop( xTask->getContainerWindow(), UNO_QUERY );
xTop->toFront();
}
else
{
// no visible task that could be activated found
- Reference< ::com::sun::star::awt::XWindow > xContainerWindow;
+ Reference< css::awt::XWindow > xContainerWindow;
Reference< XFrame > xBackingFrame = xDesktop->findFrame(OUString( "_blank" ), 0);
if (xBackingFrame.is())
xContainerWindow = xBackingFrame->getContainerWindow();
if (xContainerWindow.is())
{
Reference< XController > xStartModule = StartModule::createWithParentWindow(xContext, xContainerWindow);
- Reference< ::com::sun::star::awt::XWindow > xBackingWin(xStartModule, UNO_QUERY);
+ Reference< css::awt::XWindow > xBackingWin(xStartModule, UNO_QUERY);
// Attention: You MUST(!) call setComponent() before you call attachFrame().
// Because the backing component set the property "IsBackingMode" of the frame
// to true inside attachFrame(). But setComponent() reset this state every time ...
@@ -2707,7 +2705,7 @@ void Desktop::DoFirstRunInitializations()
Reference< XJobExecutor > xExecutor = theJobExecutor::get( ::comphelper::getProcessComponentContext() );
xExecutor->trigger( OUString("onFirstRunInitialization") );
}
- catch(const ::com::sun::star::uno::Exception&)
+ catch(const css::uno::Exception&)
{
SAL_WARN( "desktop.app", "Desktop::DoFirstRunInitializations: caught an exception while trigger job executor ..." );
}
@@ -2726,7 +2724,7 @@ void Desktop::ShowBackingComponent(Desktop * progress)
progress->SetSplashScreenProgress(60);
}
Reference< XFrame > xBackingFrame = xDesktop->findFrame(OUString( "_blank" ), 0);
- Reference< ::com::sun::star::awt::XWindow > xContainerWindow;
+ Reference< css::awt::XWindow > xContainerWindow;
if (xBackingFrame.is())
xContainerWindow = xBackingFrame->getContainerWindow();
diff --git a/desktop/source/app/appinit.cxx b/desktop/source/app/appinit.cxx
index 7928ad027e13..b321eefa96cb 100644
--- a/desktop/source/app/appinit.cxx
+++ b/desktop/source/app/appinit.cxx
@@ -154,7 +154,7 @@ void Desktop::createAcceptor(const OUString& aAcceptString)
rAcceptor->initialize( aSeq );
rMap.insert(AcceptorMap::value_type(aAcceptString, rAcceptor));
}
- catch (const com::sun::star::uno::Exception& e)
+ catch (const css::uno::Exception& e)
{
// no error handling needed...
// acceptor just won't come up
diff --git a/desktop/source/app/check_ext_deps.cxx b/desktop/source/app/check_ext_deps.cxx
index c746eb367961..7b1511b8a987 100644
--- a/desktop/source/app/check_ext_deps.cxx
+++ b/desktop/source/app/check_ext_deps.cxx
@@ -379,7 +379,7 @@ static bool impl_needsCompatCheck()
bNeedsCheck = true;
#endif
}
- catch (const com::sun::star::uno::Exception&) {}
+ catch (const css::uno::Exception&) {}
return bNeedsCheck;
}
diff --git a/desktop/source/app/cmdlineargs.cxx b/desktop/source/app/cmdlineargs.cxx
index a9526c4c8cc1..1aab71434420 100644
--- a/desktop/source/app/cmdlineargs.cxx
+++ b/desktop/source/app/cmdlineargs.cxx
@@ -49,7 +49,7 @@ namespace {
OUString translateExternalUris(OUString const & input) {
OUString t(
- com::sun::star::uri::ExternalUriReferenceTranslator::create(
+ css::uri::ExternalUriReferenceTranslator::create(
comphelper::getProcessComponentContext())->
translateToInternal(input));
return t.isEmpty() ? input : t;
diff --git a/desktop/source/app/desktopcontext.hxx b/desktop/source/app/desktopcontext.hxx
index cc7e68d30d96..2a211d1a85ae 100644
--- a/desktop/source/app/desktopcontext.hxx
+++ b/desktop/source/app/desktopcontext.hxx
@@ -25,17 +25,17 @@
namespace desktop
{
- class DesktopContext: public cppu::WeakImplHelper< com::sun::star::uno::XCurrentContext >
+ class DesktopContext: public cppu::WeakImplHelper< css::uno::XCurrentContext >
{
public:
- explicit DesktopContext( const com::sun::star::uno::Reference< com::sun::star::uno::XCurrentContext > & ctx);
+ explicit DesktopContext( const css::uno::Reference< css::uno::XCurrentContext > & ctx);
// XCurrentContext
- virtual com::sun::star::uno::Any SAL_CALL getValueByName( const OUString& Name )
- throw (com::sun::star::uno::RuntimeException, std::exception) SAL_OVERRIDE;
+ virtual css::uno::Any SAL_CALL getValueByName( const OUString& Name )
+ throw (css::uno::RuntimeException, std::exception) SAL_OVERRIDE;
private:
- com::sun::star::uno::Reference< com::sun::star::uno::XCurrentContext > m_xNextContext;
+ css::uno::Reference< css::uno::XCurrentContext > m_xNextContext;
};
}
diff --git a/desktop/source/app/dispatchwatcher.cxx b/desktop/source/app/dispatchwatcher.cxx
index 77d04a2b77f2..3bf045c6a527 100644
--- a/desktop/source/app/dispatchwatcher.cxx
+++ b/desktop/source/app/dispatchwatcher.cxx
@@ -276,11 +276,11 @@ bool DispatchWatcher::executeDispatchRequests( const DispatchList& aDispatchRequ
aArgs[1].Name = "InteractionHandler";
aArgs[1].Value <<= xInteraction;
- sal_Int16 nMacroExecMode = ::com::sun::star::document::MacroExecMode::USE_CONFIG;
+ sal_Int16 nMacroExecMode = css::document::MacroExecMode::USE_CONFIG;
aArgs[2].Name = "MacroExecutionMode";
aArgs[2].Value <<= nMacroExecMode;
- sal_Int16 nUpdateDoc = ::com::sun::star::document::UpdateDocMode::ACCORDING_TO_CONFIG;
+ sal_Int16 nUpdateDoc = css::document::UpdateDocMode::ACCORDING_TO_CONFIG;
aArgs[3].Name = "UpdateDocMode";
aArgs[3].Value <<= nUpdateDoc;
}
@@ -384,7 +384,7 @@ bool DispatchWatcher::executeDispatchRequests( const DispatchList& aDispatchRequ
else
xDispatcher->dispatch( aURL, aArgs2 );
}
- catch (const ::com::sun::star::uno::Exception& e)
+ catch (const css::uno::Exception& e)
{
SAL_WARN(
"desktop.app",
@@ -457,14 +457,14 @@ bool DispatchWatcher::executeDispatchRequests( const DispatchList& aDispatchRequ
{
xDoc = Reference < XPrintable >( ::comphelper::SynchronousDispatch::dispatch( xDesktop, aName, aTarget, 0, aArgs ), UNO_QUERY );
}
- catch (const ::com::sun::star::lang::IllegalArgumentException& iae)
+ catch (const css::lang::IllegalArgumentException& iae)
{
SAL_WARN(
"desktop.app",
"Dispatchwatcher IllegalArgumentException while calling"
" loadComponentFromURL: \"" << iae.Message << "\"");
}
- catch (const com::sun::star::io::IOException& ioe)
+ catch (const css::io::IOException& ioe)
{
SAL_WARN(
"desktop.app",
@@ -690,7 +690,7 @@ bool DispatchWatcher::executeDispatchRequests( const DispatchList& aDispatchRequ
xComp->dispose();
}
}
- catch (const com::sun::star::util::CloseVetoException&)
+ catch (const css::util::CloseVetoException&)
{
}
@@ -749,8 +749,8 @@ bool DispatchWatcher::executeDispatchRequests( const DispatchList& aDispatchRequ
}
-void SAL_CALL DispatchWatcher::disposing( const ::com::sun::star::lang::EventObject& )
-throw(::com::sun::star::uno::RuntimeException, std::exception)
+void SAL_CALL DispatchWatcher::disposing( const css::lang::EventObject& )
+ throw(css::uno::RuntimeException, std::exception)
{
}
diff --git a/desktop/source/app/dispatchwatcher.hxx b/desktop/source/app/dispatchwatcher.hxx
index 443eb19dc2b2..08c46baa054f 100644
--- a/desktop/source/app/dispatchwatcher.hxx
+++ b/desktop/source/app/dispatchwatcher.hxx
@@ -43,7 +43,7 @@ class DispatchWatcherHashMap : public std::unordered_map< OUString, sal_Int32, O
{
};
-class DispatchWatcher : public ::cppu::WeakImplHelper< ::com::sun::star::frame::XDispatchResultListener >
+class DispatchWatcher : public ::cppu::WeakImplHelper< css::frame::XDispatchResultListener >
{
public:
enum RequestType
@@ -78,11 +78,11 @@ class DispatchWatcher : public ::cppu::WeakImplHelper< ::com::sun::star::frame::
virtual ~DispatchWatcher();
// XEventListener
- virtual void SAL_CALL disposing( const ::com::sun::star::lang::EventObject& Source )
- throw(::com::sun::star::uno::RuntimeException, std::exception) SAL_OVERRIDE;
+ virtual void SAL_CALL disposing( const css::lang::EventObject& Source )
+ throw(css::uno::RuntimeException, std::exception) SAL_OVERRIDE;
// XDispachResultListener
- virtual void SAL_CALL dispatchFinished( const com::sun::star::frame::DispatchResultEvent& aEvent ) throw( com::sun::star::uno::RuntimeException, std::exception ) SAL_OVERRIDE;
+ virtual void SAL_CALL dispatchFinished( const css::frame::DispatchResultEvent& aEvent ) throw( css::uno::RuntimeException, std::exception ) SAL_OVERRIDE;
// Access function to get a dispatcher watcher reference. There must be a global reference holder
static DispatchWatcher* GetDispatchWatcher();
diff --git a/desktop/source/app/langselect.cxx b/desktop/source/app/langselect.cxx
index d57a68f75cb9..977c65770499 100644
--- a/desktop/source/app/langselect.cxx
+++ b/desktop/source/app/langselect.cxx
@@ -179,7 +179,7 @@ bool prepareLocale() {
// locale this will ensure localized configuration settings to be
// selected according to the UI language:
css::uno::Reference<css::lang::XLocalizable>(
- com::sun::star::configuration::theDefaultProvider::get(
+ css::configuration::theDefaultProvider::get(
comphelper::getProcessComponentContext()),
css::uno::UNO_QUERY_THROW)->setLocale(tag.getLocale(false));
if (!cmdLanguage) {
diff --git a/desktop/source/app/officeipcthread.hxx b/desktop/source/app/officeipcthread.hxx
index add93768efa8..e3902261a54d 100644
--- a/desktop/source/app/officeipcthread.hxx
+++ b/desktop/source/app/officeipcthread.hxx
@@ -128,8 +128,8 @@ class OfficeIPCThread : public salhelper::Thread
class OfficeIPCThreadController : public ::cppu::WeakImplHelper<
- ::com::sun::star::lang::XServiceInfo,
- ::com::sun::star::frame::XTerminateListener >
+ css::lang::XServiceInfo,
+ css::frame::XTerminateListener >
{
public:
OfficeIPCThreadController() {}
@@ -137,21 +137,21 @@ class OfficeIPCThreadController : public ::cppu::WeakImplHelper<
// XServiceInfo
virtual OUString SAL_CALL getImplementationName()
- throw ( ::com::sun::star::uno::RuntimeException, std::exception ) SAL_OVERRIDE;
+ throw ( css::uno::RuntimeException, std::exception ) SAL_OVERRIDE;
virtual sal_Bool SAL_CALL supportsService( const OUString& ServiceName )
- throw ( ::com::sun::star::uno::RuntimeException, std::exception ) SAL_OVERRIDE;
- virtual ::com::sun::star::uno::Sequence< OUString > SAL_CALL getSupportedServiceNames()
- throw ( ::com::sun::star::uno::RuntimeException, std::exception ) SAL_OVERRIDE;
+ throw ( css::uno::RuntimeException, std::exception ) SAL_OVERRIDE;
+ virtual css::uno::Sequence< OUString > SAL_CALL getSupportedServiceNames()
+ throw ( css::uno::RuntimeException, std::exception ) SAL_OVERRIDE;
// XEventListener
- virtual void SAL_CALL disposing( const ::com::sun::star::lang::EventObject& Source )
- throw( ::com::sun::star::uno::RuntimeException, std::exception ) SAL_OVERRIDE;
+ virtual void SAL_CALL disposing( const css::lang::EventObject& Source )
+ throw( css::uno::RuntimeException, std::exception ) SAL_OVERRIDE;
// XTerminateListener
- virtual void SAL_CALL queryTermination( const ::com::sun::star::lang::EventObject& aEvent )
- throw( ::com::sun::star::frame::TerminationVetoException, ::com::sun::star::uno::RuntimeException, std::exception ) SAL_OVERRIDE;
- virtual void SAL_CALL notifyTermination( const ::com::sun::star::lang::EventObject& aEvent )
- throw( ::com::sun::star::uno::RuntimeException, std::exception ) SAL_OVERRIDE;
+ virtual void SAL_CALL queryTermination( const css::lang::EventObject& aEvent )
+ throw( css::frame::TerminationVetoException, css::uno::RuntimeException, std::exception ) SAL_OVERRIDE;
+ virtual void SAL_CALL notifyTermination( const css::lang::EventObject& aEvent )
+ throw( css::uno::RuntimeException, std::exception ) SAL_OVERRIDE;
};
}
diff --git a/desktop/source/app/sofficemain.cxx b/desktop/source/app/sofficemain.cxx
index 48aafb70c497..b567cc9dfe40 100644
--- a/desktop/source/app/sofficemain.cxx
+++ b/desktop/source/app/sofficemain.cxx
@@ -95,7 +95,7 @@ extern "C" int DESKTOP_DLLPUBLIC soffice_main()
#endif
return SVMain();
#if defined ANDROID
- } catch (const ::com::sun::star::uno::Exception &e) {
+ } catch (const css::uno::Exception &e) {
LOGI("Unhandled UNO exception: '%s'",
OUStringToOString(e.Message, RTL_TEXTENCODING_UTF8).getStr());
throw; // to get exception type printed
diff --git a/desktop/source/deployment/gui/dp_gui.h b/desktop/source/deployment/gui/dp_gui.h
index 468b14b2ccae..71a97b9b1b3c 100644
--- a/desktop/source/deployment/gui/dp_gui.h
+++ b/desktop/source/deployment/gui/dp_gui.h
@@ -68,7 +68,7 @@ enum PackageState { REGISTERED, NOT_REGISTERED, AMBIGUOUS, NOT_AVAILABLE };
class SelectedPackage: public salhelper::SimpleReferenceObject {
public:
SelectedPackage() {}
- explicit SelectedPackage( const ::com::sun::star::uno::Reference< ::com::sun::star::deployment::XPackage> &xPackage)
+ explicit SelectedPackage( const css::uno::Reference< css::deployment::XPackage> &xPackage)
: m_xPackage( xPackage )
{}
@@ -78,7 +78,7 @@ private:
SelectedPackage(SelectedPackage &) SAL_DELETED_FUNCTION;
void operator =(SelectedPackage &) SAL_DELETED_FUNCTION;
- ::com::sun::star::uno::Reference< ::com::sun::star::deployment::XPackage> m_xPackage;
+ css::uno::Reference< css::deployment::XPackage> m_xPackage;
};
} // namespace dp_gui
diff --git a/desktop/source/deployment/gui/dp_gui_dialog2.hxx b/desktop/source/deployment/gui/dp_gui_dialog2.hxx
index 8f7b3009f604..7df43d1ffe54 100644
--- a/desktop/source/deployment/gui/dp_gui_dialog2.hxx
+++ b/desktop/source/deployment/gui/dp_gui_dialog2.hxx
@@ -56,13 +56,13 @@ class TheExtensionManager;
class DialogHelper
{
- ::com::sun::star::uno::Reference< ::com::sun::star::uno::XComponentContext > m_xContext;
+ css::uno::Reference< css::uno::XComponentContext > m_xContext;
VclPtr<Dialog> m_pVCLWindow;
ImplSVEvent * m_nEventID;
bool m_bIsBusy;
public:
- DialogHelper( const ::com::sun::star::uno::Reference< ::com::sun::star::uno::XComponentContext > &,
+ DialogHelper( const css::uno::Reference< css::uno::XComponentContext > &,
Dialog *pWindow );
virtual ~DialogHelper();
@@ -73,11 +73,11 @@ public:
virtual void showProgress( bool bStart ) = 0;
virtual void updateProgress( const OUString &rText,
- const ::com::sun::star::uno::Reference< ::com::sun::star::task::XAbortChannel > &xAbortChannel) = 0;
+ const css::uno::Reference< css::task::XAbortChannel > &xAbortChannel) = 0;
virtual void updateProgress( const long nProgress ) = 0;
- virtual void updatePackageInfo( const ::com::sun::star::uno::Reference< ::com::sun::star::deployment::XPackage > &xPackage ) = 0;
- virtual long addPackageToList( const ::com::sun::star::uno::Reference< ::com::sun::star::deployment::XPackage > &xPackage,
+ virtual void updatePackageInfo( const css::uno::Reference< css::deployment::XPackage > &xPackage ) = 0;
+ virtual long addPackageToList( const css::uno::Reference< css::deployment::XPackage > &xPackage,
bool bLicenseMissing = false ) = 0;
virtual void prepareChecking() = 0;
@@ -85,8 +85,8 @@ public:
static ResId getResId( sal_uInt16 nId );
static OUString getResourceString( sal_uInt16 id );
- static bool IsSharedPkgMgr( const ::com::sun::star::uno::Reference< ::com::sun::star::deployment::XPackage > &);
- static bool continueOnSharedExtension( const ::com::sun::star::uno::Reference< ::com::sun::star::deployment::XPackage > &,
+ static bool IsSharedPkgMgr( const css::uno::Reference< css::deployment::XPackage > &);
+ static bool continueOnSharedExtension( const css::uno::Reference< css::deployment::XPackage > &,
vcl::Window *pParent,
const sal_uInt16 nResID,
bool &bHadWarning );
@@ -127,7 +127,7 @@ class ExtMgrDialog : public ModelessDialog,
Idle m_aIdle;
TheExtensionManager *m_pManager;
- ::com::sun::star::uno::Reference< ::com::sun::star::task::XAbortChannel > m_xAbortChannel;
+ css::uno::Reference< css::task::XAbortChannel > m_xAbortChannel;
bool removeExtensionWarn( const OUString &rExtensionTitle ) const;
@@ -150,26 +150,26 @@ public:
virtual void showProgress( bool bStart ) SAL_OVERRIDE;
virtual void updateProgress( const OUString &rText,
- const ::com::sun::star::uno::Reference< ::com::sun::star::task::XAbortChannel > &xAbortChannel) SAL_OVERRIDE;
+ const css::uno::Reference< css::task::XAbortChannel > &xAbortChannel) SAL_OVERRIDE;
virtual void updateProgress( const long nProgress ) SAL_OVERRIDE;
- virtual void updatePackageInfo( const ::com::sun::star::uno::Reference< ::com::sun::star::deployment::XPackage > &xPackage ) SAL_OVERRIDE;
+ virtual void updatePackageInfo( const css::uno::Reference< css::deployment::XPackage > &xPackage ) SAL_OVERRIDE;
void setGetExtensionsURL( const OUString &rURL );
- virtual long addPackageToList( const ::com::sun::star::uno::Reference< ::com::sun::star::deployment::XPackage > &,
+ virtual long addPackageToList( const css::uno::Reference< css::deployment::XPackage > &,
bool bLicenseMissing = false ) SAL_OVERRIDE;
- bool enablePackage(const ::com::sun::star::uno::Reference< ::com::sun::star::deployment::XPackage > &xPackage,
+ bool enablePackage(const css::uno::Reference< css::deployment::XPackage > &xPackage,
bool bEnable );
- bool removePackage(const ::com::sun::star::uno::Reference< ::com::sun::star::deployment::XPackage > &xPackage );
- bool updatePackage(const ::com::sun::star::uno::Reference< ::com::sun::star::deployment::XPackage > &xPackage );
- bool acceptLicense(const ::com::sun::star::uno::Reference< ::com::sun::star::deployment::XPackage > &xPackage );
+ bool removePackage(const css::uno::Reference< css::deployment::XPackage > &xPackage );
+ bool updatePackage(const css::uno::Reference< css::deployment::XPackage > &xPackage );
+ bool acceptLicense(const css::uno::Reference< css::deployment::XPackage > &xPackage );
TheExtensionManager* getExtensionManager() const { return m_pManager; }
virtual void prepareChecking() SAL_OVERRIDE;
virtual void checkEntries() SAL_OVERRIDE;
- ::com::sun::star::uno::Sequence< OUString > raiseAddPicker();
+ css::uno::Sequence< OUString > raiseAddPicker();
};
@@ -195,7 +195,7 @@ class UpdateRequiredDialog : public ModalDialog,
Idle m_aIdle;
TheExtensionManager *m_pManager;
- ::com::sun::star::uno::Reference< ::com::sun::star::task::XAbortChannel > m_xAbortChannel;
+ css::uno::Reference< css::task::XAbortChannel > m_xAbortChannel;
DECL_DLLPRIVATE_LINK_TYPED( HandleUpdateBtn, Button*, void );
DECL_DLLPRIVATE_LINK_TYPED( HandleCloseBtn, Button*, void );
@@ -204,8 +204,8 @@ class UpdateRequiredDialog : public ModalDialog,
DECL_DLLPRIVATE_LINK_TYPED( startProgress, void *, void );
DECL_DLLPRIVATE_LINK( HandleHyperlink, FixedHyperlink * );
- static bool isEnabled( const ::com::sun::star::uno::Reference< ::com::sun::star::deployment::XPackage > &xPackage );
- static bool checkDependencies( const ::com::sun::star::uno::Reference< ::com::sun::star::deployment::XPackage > &xPackage );
+ static bool isEnabled( const css::uno::Reference< css::deployment::XPackage > &xPackage );
+ static bool checkDependencies( const css::uno::Reference< css::deployment::XPackage > &xPackage );
bool hasActiveEntries();
void disableAllEntries();
@@ -219,14 +219,14 @@ public:
virtual void showProgress( bool bStart ) SAL_OVERRIDE;
virtual void updateProgress( const OUString &rText,
- const ::com::sun::star::uno::Reference< ::com::sun::star::task::XAbortChannel > &xAbortChannel) SAL_OVERRIDE;
+ const css::uno::Reference< css::task::XAbortChannel > &xAbortChannel) SAL_OVERRIDE;
virtual void updateProgress( const long nProgress ) SAL_OVERRIDE;
- virtual void updatePackageInfo( const ::com::sun::star::uno::Reference< ::com::sun::star::deployment::XPackage > &xPackage ) SAL_OVERRIDE;
+ virtual void updatePackageInfo( const css::uno::Reference< css::deployment::XPackage > &xPackage ) SAL_OVERRIDE;
- virtual long addPackageToList( const ::com::sun::star::uno::Reference< ::com::sun::star::deployment::XPackage > &,
+ virtual long addPackageToList( const css::uno::Reference< css::deployment::XPackage > &,
bool bLicenseMissing = false ) SAL_OVERRIDE;
- bool enablePackage( const ::com::sun::star::uno::Reference< ::com::sun::star::deployment::XPackage > &xPackage, bool bEnable );
+ bool enablePackage( const css::uno::Reference< css::deployment::XPackage > &xPackage, bool bEnable );
virtual void prepareChecking() SAL_OVERRIDE;
virtual void checkEntries() SAL_OVERRIDE;
@@ -243,17 +243,17 @@ public:
};
-class UpdateRequiredDialogService : public ::cppu::WeakImplHelper< ::com::sun::star::ui::dialogs::XExecutableDialog >
+class UpdateRequiredDialogService : public ::cppu::WeakImplHelper< css::ui::dialogs::XExecutableDialog >
{
- ::com::sun::star::uno::Reference< ::com::sun::star::uno::XComponentContext > const m_xComponentContext;
- ::com::sun::star::uno::Reference< ::com::sun::star::awt::XWindow > m_xParent;
+ css::uno::Reference< css::uno::XComponentContext > const m_xComponentContext;
+ css::uno::Reference< css::awt::XWindow > m_xParent;
public:
- UpdateRequiredDialogService( ::com::sun::star::uno::Sequence< ::com::sun::star::uno::Any > const & args,
- ::com::sun::star::uno::Reference< ::com::sun::star::uno::XComponentContext> const & xComponentContext );
+ UpdateRequiredDialogService( css::uno::Sequence< css::uno::Any > const & args,
+ css::uno::Reference< css::uno::XComponentContext> const & xComponentContext );
// XExecutableDialog
- virtual void SAL_CALL setTitle( OUString const & title ) throw ( ::com::sun::star::uno::RuntimeException, std::exception ) SAL_OVERRIDE;
- virtual sal_Int16 SAL_CALL execute() throw ( ::com::sun::star::uno::RuntimeException, std::exception ) SAL_OVERRIDE;
+ virtual void SAL_CALL setTitle( OUString const & title ) throw ( css::uno::RuntimeException, std::exception ) SAL_OVERRIDE;
+ virtual sal_Int16 SAL_CALL execute() throw ( css::uno::RuntimeException, std::exception ) SAL_OVERRIDE;
};
} // namespace dp_gui
diff --git a/desktop/source/deployment/gui/dp_gui_extensioncmdqueue.hxx b/desktop/source/deployment/gui/dp_gui_extensioncmdqueue.hxx
index c4bec998081e..e6aaac9bd783 100644
--- a/desktop/source/deployment/gui/dp_gui_extensioncmdqueue.hxx
+++ b/desktop/source/deployment/gui/dp_gui_extensioncmdqueue.hxx
@@ -63,7 +63,7 @@ public:
*/
ExtensionCmdQueue( DialogHelper * pDialogHelper,
TheExtensionManager *pManager,
- const ::com::sun::star::uno::Reference< ::com::sun::star::uno::XComponentContext > & rContext);
+ const css::uno::Reference< css::uno::XComponentContext > & rContext);
~ExtensionCmdQueue();
@@ -72,13 +72,13 @@ public:
void addExtension( const OUString &rExtensionURL,
const OUString &rRepository,
const bool bWarnUser );
- void removeExtension( const ::com::sun::star::uno::Reference< ::com::sun::star::deployment::XPackage > &rPackage );
- void enableExtension( const ::com::sun::star::uno::Reference< ::com::sun::star::deployment::XPackage > &rPackage,
+ void removeExtension( const css::uno::Reference< css::deployment::XPackage > &rPackage );
+ void enableExtension( const css::uno::Reference< css::deployment::XPackage > &rPackage,
const bool bEnable );
- void checkForUpdates(const std::vector< ::com::sun::star::uno::Reference<
- ::com::sun::star::deployment::XPackage > > &vList );
- void acceptLicense( const ::com::sun::star::uno::Reference< ::com::sun::star::deployment::XPackage > &rPackage );
- static void syncRepositories( const ::com::sun::star::uno::Reference< ::com::sun::star::uno::XComponentContext > & xContext );
+ void checkForUpdates(const std::vector< css::uno::Reference<
+ css::deployment::XPackage > > &vList );
+ void acceptLicense( const css::uno::Reference< css::deployment::XPackage > &rPackage );
+ static void syncRepositories( const css::uno::Reference< css::uno::XComponentContext > & xContext );
/**
This call does not block. It signals the internal thread
that it should install the remaining extensions and then terminate.
@@ -95,8 +95,8 @@ private:
rtl::Reference< Thread > m_thread;
};
-void handleInteractionRequest( const ::com::sun::star::uno::Reference< ::com::sun::star::uno::XComponentContext > & xContext,
- const ::com::sun::star::uno::Reference< ::com::sun::star::task::XInteractionRequest > & xRequest );
+void handleInteractionRequest( const css::uno::Reference< css::uno::XComponentContext > & xContext,
+ const css::uno::Reference< css::task::XInteractionRequest > & xRequest );
}
diff --git a/desktop/source/deployment/gui/dp_gui_theextmgr.hxx b/desktop/source/deployment/gui/dp_gui_theextmgr.hxx
index 76bcc1f9be1a..a66630342012 100644
--- a/desktop/source/deployment/gui/dp_gui_theextmgr.hxx
+++ b/desktop/source/deployment/gui/dp_gui_theextmgr.hxx
@@ -44,22 +44,20 @@ class ExtensionCmdQueue;
class TheExtensionManager :
- public ::cppu::WeakImplHelper< ::com::sun::star::frame::XTerminateListener,
- ::com::sun::star::util::XModifyListener >
+ public ::cppu::WeakImplHelper< css::frame::XTerminateListener,
+ css::util::XModifyListener >
{
private:
- ::com::sun::star::uno::Reference< ::com::sun::star::uno::XComponentContext > m_xContext;
- ::com::sun::star::uno::Reference< ::com::sun::star::frame::XDesktop2 > m_xDesktop;
- ::com::sun::star::uno::Reference< ::com::sun::star::deployment::XExtensionManager > m_xExtensionManager;
- ::com::sun::star::uno::Reference< ::com::sun::star::container::XNameAccess > m_xNameAccessNodes;
-
- css::uno::Reference<
- css::awt::XWindow > m_xParent;
+ css::uno::Reference< css::uno::XComponentContext > m_xContext;
+ css::uno::Reference< css::frame::XDesktop2 > m_xDesktop;
+ css::uno::Reference< css::deployment::XExtensionManager > m_xExtensionManager;
+ css::uno::Reference< css::container::XNameAccess > m_xNameAccessNodes;
+ css::uno::Reference< css::awt::XWindow > m_xParent;
VclPtr<ExtMgrDialog> m_pExtMgrDialog;
VclPtr<UpdateRequiredDialog> m_pUpdReqDialog;
ExtensionCmdQueue *m_pExecuteCmdQueue;
- OUString m_sGetExtensionsURL;
+ OUString m_sGetExtensionsURL;
public:
static ::rtl::Reference<TheExtensionManager> s_ExtMgr;
@@ -100,31 +98,31 @@ public:
void terminateDialog();
// Tools
- bool supportsOptions( const ::com::sun::star::uno::Reference< ::com::sun::star::deployment::XPackage > &xPackage ) const;
- static PackageState getPackageState( const ::com::sun::star::uno::Reference< ::com::sun::star::deployment::XPackage > &xPackage );
- ::com::sun::star::uno::Reference< ::com::sun::star::uno::XComponentContext > getContext() const { return m_xContext; }
- ::com::sun::star::uno::Reference< ::com::sun::star::deployment::XExtensionManager > getExtensionManager() const { return m_xExtensionManager; }
- bool isReadOnly( const ::com::sun::star::uno::Reference< ::com::sun::star::deployment::XPackage > &xPackage ) const;
+ bool supportsOptions( const css::uno::Reference< css::deployment::XPackage > &xPackage ) const;
+ static PackageState getPackageState( const css::uno::Reference< css::deployment::XPackage > &xPackage );
+ css::uno::Reference< css::uno::XComponentContext > getContext() const { return m_xContext; }
+ css::uno::Reference< css::deployment::XExtensionManager > getExtensionManager() const { return m_xExtensionManager; }
+ bool isReadOnly( const css::uno::Reference< css::deployment::XPackage > &xPackage ) const;
static ::rtl::Reference<TheExtensionManager> get(
- ::com::sun::star::uno::Reference< ::com::sun::star::uno::XComponentContext> const & xContext,
- ::com::sun::star::uno::Reference< ::com::sun::star::awt::XWindow> const & xParent = 0,
+ css::uno::Reference< css::uno::XComponentContext> const & xContext,
+ css::uno::Reference< css::awt::XWindow> const & xParent = 0,
OUString const & view = OUString() );
// XEventListener
- virtual void SAL_CALL disposing( ::com::sun::star::lang::EventObject const & evt )
- throw (::com::sun::star::uno::RuntimeException, std::exception) SAL_OVERRIDE;
+ virtual void SAL_CALL disposing( css::lang::EventObject const & evt )
+ throw (css::uno::RuntimeException, std::exception) SAL_OVERRIDE;
// XTerminateListener
- virtual void SAL_CALL queryTermination( ::com::sun::star::lang::EventObject const & evt )
- throw (::com::sun::star::frame::TerminationVetoException, ::com::sun::star::uno::RuntimeException, std::exception) SAL_OVERRIDE;
- virtual void SAL_CALL notifyTermination( ::com::sun::star::lang::EventObject const & evt )
- throw (::com::sun::star::uno::RuntimeException, std::exception) SAL_OVERRIDE;
+ virtual void SAL_CALL queryTermination( css::lang::EventObject const & evt )
+ throw (css::frame::TerminationVetoException, css::uno::RuntimeException, std::exception) SAL_OVERRIDE;
+ virtual void SAL_CALL notifyTermination( css::lang::EventObject const & evt )
+ throw (css::uno::RuntimeException, std::exception) SAL_OVERRIDE;
// XModifyListener
- virtual void SAL_CALL modified( ::com::sun::star::lang::EventObject const & evt )
- throw (::com::sun::star::uno::RuntimeException, std::exception) SAL_OVERRIDE;
+ virtual void SAL_CALL modified( css::lang::EventObject const & evt )
+ throw (css::uno::RuntimeException, std::exception) SAL_OVERRIDE;
};
} // namespace dp_gui
diff --git a/desktop/source/deployment/gui/dp_gui_updatedata.hxx b/desktop/source/deployment/gui/dp_gui_updatedata.hxx
index ce6885da7349..1f6d5236de94 100644
--- a/desktop/source/deployment/gui/dp_gui_updatedata.hxx
+++ b/desktop/source/deployment/gui/dp_gui_updatedata.hxx
@@ -38,7 +38,7 @@ namespace dp_gui {
struct UpdateData
{
- explicit UpdateData( ::com::sun::star::uno::Reference< ::com::sun::star::deployment::XPackage > const & aExt):
+ explicit UpdateData( css::uno::Reference< css::deployment::XPackage > const & aExt):
bIsShared(false), aInstalledPackage(aExt), aUpdateSource(NULL), m_nID(0), m_bIgnored(false){};
//When entries added to the listbox then there can be one for the user update and one
@@ -48,7 +48,7 @@ struct UpdateData
//The currently installed extension which is going to be updated. If the extension exist in
//multiple repositories then it is the one with the highest version.
- ::com::sun::star::uno::Reference< ::com::sun::star::deployment::XPackage > aInstalledPackage;
+ css::uno::Reference< css::deployment::XPackage > aInstalledPackage;
//The version of the update
OUString updateVersion;
@@ -58,7 +58,7 @@ struct UpdateData
// The content of the update information.
//Only if aUpdateInfo is set then there is an online update available with a better version
//than any of the currently installed extensions with the same identifier.
- ::com::sun::star::uno::Reference< ::com::sun::star::xml::dom::XNode > aUpdateInfo;
+ css::uno::Reference< css::xml::dom::XNode > aUpdateInfo;
//The URL of the locally downloaded extension. It will only be set if there were no errors
//during the download
OUString sLocalURL;
@@ -70,7 +70,7 @@ struct UpdateData
//The locale extension which is used as update for the user or shared repository.
//If set then the data for the online update (aUpdateInfo, sLocalURL, sWebsiteURL)
//are to be ignored.
- ::com::sun::star::uno::Reference< ::com::sun::star::deployment::XPackage >
+ css::uno::Reference< css::deployment::XPackage >
aUpdateSource;
// ID to find this entry in the update listbox
diff --git a/desktop/source/deployment/gui/dp_gui_updatedialog.cxx b/desktop/source/deployment/gui/dp_gui_updatedialog.cxx
index bb2d84f466cc..4cc82d602f44 100644
--- a/desktop/source/deployment/gui/dp_gui_updatedialog.cxx
+++ b/desktop/source/deployment/gui/dp_gui_updatedialog.cxx
@@ -147,11 +147,11 @@ OUString confineToParagraph(OUString const & text) {
}
struct UpdateDialog::DisabledUpdate {
- OUString name;
+ OUString name;
uno::Sequence< OUString > unsatisfiedDependencies;
// We also want to show release notes and publisher for disabled updates
- ::com::sun::star::uno::Reference< ::com::sun::star::xml::dom::XNode > aUpdateInfo;
- sal_uInt16 m_nID;
+ css::uno::Reference< css::xml::dom::XNode > aUpdateInfo;
+ sal_uInt16 m_nID;
};
struct UpdateDialog::SpecificError {
@@ -222,7 +222,7 @@ private:
dp_gui::UpdateData const & data, OUString const & version = OUString()) const;
void prepareUpdateData(
- ::com::sun::star::uno::Reference< ::com::sun::star::xml::dom::XNode > const & updateInfo,
+ css::uno::Reference< css::xml::dom::XNode > const & updateInfo,
UpdateDialog::DisabledUpdate & out_du,
dp_gui::UpdateData & out_data) const;
@@ -1330,10 +1330,10 @@ IMPL_LINK( UpdateDialog, hyperlink_clicked, FixedHyperlink*, pHyperlink )
try
{
- uno::Reference< com::sun::star::system::XSystemShellExecute > xSystemShellExecute(
- com::sun::star::system::SystemShellExecute::create(m_context) );
+ uno::Reference< css::system::XSystemShellExecute > xSystemShellExecute(
+ css::system::SystemShellExecute::create(m_context) );
//throws lang::IllegalArgumentException, system::SystemShellExecuteException
- xSystemShellExecute->execute( sURL, OUString(), com::sun::star::system::SystemShellExecuteFlags::URIS_ONLY);
+ xSystemShellExecute->execute( sURL, OUString(), css::system::SystemShellExecuteFlags::URIS_ONLY);
}
catch ( const uno::Exception& )
{
diff --git a/desktop/source/deployment/gui/dp_gui_updatedialog.hxx b/desktop/source/deployment/gui/dp_gui_updatedialog.hxx
index 81dd5ce4c4f0..f4807c831e41 100644
--- a/desktop/source/deployment/gui/dp_gui_updatedialog.hxx
+++ b/desktop/source/deployment/gui/dp_gui_updatedialog.hxx
@@ -78,10 +78,10 @@ public:
information.
*/
UpdateDialog(
- com::sun::star::uno::Reference< com::sun::star::uno::XComponentContext > const & context,
+ css::uno::Reference< css::uno::XComponentContext > const & context,
vcl::Window * parent,
- const std::vector< com::sun::star::uno::Reference<
- com::sun::star::deployment::XPackage > > & vExtensionList,
+ const std::vector< css::uno::Reference<
+ css::deployment::XPackage > > & vExtensionList,
std::vector< dp_gui::UpdateData > * updateData);
virtual ~UpdateDialog();
@@ -93,7 +93,7 @@ public:
void notifyMenubar( bool bPrepareOnly, bool bRecheckOnly );
static void createNotifyJob( bool bPrepareOnly,
- com::sun::star::uno::Sequence< com::sun::star::uno::Sequence< OUString > > &rItemList );
+ css::uno::Sequence< css::uno::Sequence< OUString > > &rItemList );
private:
UpdateDialog(UpdateDialog &) SAL_DELETED_FUNCTION;
@@ -151,12 +151,12 @@ private:
void initDescription();
void clearDescription();
- bool showDescription(::com::sun::star::uno::Reference<
- ::com::sun::star::deployment::XPackage > const & aExtension);
+ bool showDescription(css::uno::Reference<
+ css::deployment::XPackage > const & aExtension);
bool showDescription(std::pair< OUString, OUString > const & pairPublisher,
OUString const & sReleaseNotes);
- bool showDescription( ::com::sun::star::uno::Reference<
- ::com::sun::star::xml::dom::XNode > const & aUpdateInfo);
+ bool showDescription( css::uno::Reference<
+ css::xml::dom::XNode > const & aUpdateInfo);
bool showDescription( const OUString& rDescription);
DECL_LINK_TYPED(selectionHandler, SvTreeListBox*, void);
@@ -165,8 +165,7 @@ private:
DECL_LINK_TYPED(closeHandler, Button*, void);
DECL_LINK(hyperlink_clicked, FixedHyperlink *);
- com::sun::star::uno::Reference< com::sun::star::uno::XComponentContext >
- m_context;
+ css::uno::Reference< css::uno::XComponentContext > m_context;
VclPtr<FixedText> m_pchecking;
VclPtr<Throbber> m_pthrobber;
VclPtr<FixedText> m_pUpdate;
@@ -200,7 +199,7 @@ private:
std::vector< Index* > m_ListboxEntries;
std::vector< dp_gui::UpdateData > & m_updateData;
rtl::Reference< UpdateDialog::Thread > m_thread;
- ::com::sun::star::uno::Reference< ::com::sun::star::deployment::XExtensionManager > m_xExtensionManager;
+ css::uno::Reference< css::deployment::XExtensionManager > m_xExtensionManager;
sal_uInt16 m_nLastID;
bool m_bModified;
diff --git a/desktop/source/deployment/gui/dp_gui_updateinstalldialog.hxx b/desktop/source/deployment/gui/dp_gui_updateinstalldialog.hxx
index 00e289a564c5..13bc6d6559fb 100644
--- a/desktop/source/deployment/gui/dp_gui_updateinstalldialog.hxx
+++ b/desktop/source/deployment/gui/dp_gui_updateinstalldialog.hxx
@@ -57,7 +57,7 @@ public:
the parent window, may be null
*/
UpdateInstallDialog(vcl::Window * parent, std::vector<UpdateData> & aVecUpdateData,
- ::com::sun::star::uno::Reference< ::com::sun::star::uno::XComponentContext > const & xCtx);
+ css::uno::Reference< css::uno::XComponentContext > const & xCtx);
virtual ~UpdateInstallDialog();
virtual void dispose() SAL_OVERRIDE;
@@ -86,12 +86,12 @@ private:
};
void setError(INSTALL_ERROR err, OUString const & sExtension, OUString const & exceptionMessage);
void setError(OUString const & exceptionMessage);
- ::com::sun::star::uno::Reference< ::com::sun::star::deployment::XExtensionManager > getExtensionManager() const
+ css::uno::Reference< css::deployment::XExtensionManager > getExtensionManager() const
{ return m_xExtensionManager; }
rtl::Reference< Thread > m_thread;
- ::com::sun::star::uno::Reference< ::com::sun::star::uno::XComponentContext > m_xComponentContext;
- ::com::sun::star::uno::Reference< ::com::sun::star::deployment::XExtensionManager > m_xExtensionManager;
+ css::uno::Reference< css::uno::XComponentContext > m_xComponentContext;
+ css::uno::Reference< css::deployment::XExtensionManager > m_xExtensionManager;
//Signals that an error occurred during download and installation
bool m_bError;
bool m_bNoEntry;
diff --git a/desktop/source/deployment/inc/dp_dependencies.hxx b/desktop/source/deployment/inc/dp_dependencies.hxx
index 1d64f3b49b40..ba8233aa9778 100644
--- a/desktop/source/deployment/inc/dp_dependencies.hxx
+++ b/desktop/source/deployment/inc/dp_dependencies.hxx
@@ -49,8 +49,8 @@ namespace Dependencies {
a list of the unsatisfied dependencies from <code>infoset</code> (in no
specific order)
*/
- DESKTOP_DEPLOYMENTMISC_DLLPUBLIC com::sun::star::uno::Sequence<
- com::sun::star::uno::Reference< com::sun::star::xml::dom::XElement > >
+ DESKTOP_DEPLOYMENTMISC_DLLPUBLIC css::uno::Sequence<
+ css::uno::Reference< css::xml::dom::XElement > >
check(dp_misc::DescriptionInfoset const & infoset);
/**
@@ -64,7 +64,7 @@ namespace Dependencies {
&ldquo;unknown&rdquo; is substituted for an empty/missing name
*/
DESKTOP_DEPLOYMENTMISC_DLLPUBLIC OUString getErrorText(
- com::sun::star::uno::Reference< com::sun::star::xml::dom::XElement >
+ css::uno::Reference< css::xml::dom::XElement >
const & dependency);
}
diff --git a/desktop/source/deployment/inc/dp_descriptioninfoset.hxx b/desktop/source/deployment/inc/dp_descriptioninfoset.hxx
index f8e7cb15a1b1..66460bc87219 100644
--- a/desktop/source/deployment/inc/dp_descriptioninfoset.hxx
+++ b/desktop/source/deployment/inc/dp_descriptioninfoset.hxx
@@ -72,10 +72,8 @@ public:
with no content)
*/
DescriptionInfoset(
- ::com::sun::star::uno::Reference<
- ::com::sun::star::uno::XComponentContext > const & context,
- ::com::sun::star::uno::Reference<
- ::com::sun::star::xml::dom::XNode > const & element);
+ css::uno::Reference< css::uno::XComponentContext > const & context,
+ css::uno::Reference< css::xml::dom::XNode > const & element);
~DescriptionInfoset();
@@ -110,7 +108,7 @@ public:
The value attribute can contain various platform tokens. They must be separated by
commas.Each token will be stripped from leading and trailing white space (trim()).
*/
- ::com::sun::star::uno::Sequence< OUString > getSupportedPlaforms() const;
+ css::uno::Sequence< OUString > getSupportedPlaforms() const;
/**
Returns the localized publisher name and the corresponding URL.
@@ -177,7 +175,7 @@ public:
@return
dependencies; will never be null
*/
- ::com::sun::star::uno::Reference< ::com::sun::star::xml::dom::XNodeList >
+ css::uno::Reference< css::xml::dom::XNodeList >
getDependencies() const;
/**
@@ -186,8 +184,7 @@ public:
@return
update information URLs
*/
- ::com::sun::star::uno::Sequence< OUString >
- getUpdateInformationUrls() const;
+ css::uno::Sequence< OUString > getUpdateInformationUrls() const;
/**
Return the download URLs from the update information.
@@ -199,8 +196,7 @@ public:
@return
download URLs
*/
- ::com::sun::star::uno::Sequence< OUString >
- getUpdateDownloadUrls() const;
+ css::uno::Sequence< OUString > getUpdateDownloadUrls() const;
/**
Returns the URL for the icon image.
@@ -213,7 +209,7 @@ private:
SAL_DLLPRIVATE ::boost::optional< OUString > getOptionalValue(
OUString const & expression) const;
- SAL_DLLPRIVATE ::com::sun::star::uno::Sequence< OUString > getUrls(
+ SAL_DLLPRIVATE css::uno::Sequence< OUString > getUrls(
OUString const & expression) const;
/** Retrieves a child element which as lang attribute which matches the office locale.
@@ -225,11 +221,11 @@ private:
the expression used to obtain the parent of the localized children. It can be null.
Then a null reference is returned.
*/
- SAL_DLLPRIVATE ::com::sun::star::uno::Reference< ::com::sun::star::xml::dom::XNode >
+ SAL_DLLPRIVATE css::uno::Reference< css::xml::dom::XNode >
getLocalizedChild( OUString const & sParent) const;
- SAL_DLLPRIVATE ::com::sun::star::uno::Reference< ::com::sun::star::xml::dom::XNode>
+ SAL_DLLPRIVATE css::uno::Reference< css::xml::dom::XNode>
matchLanguageTag(
- ::com::sun::star::uno::Reference< ::com::sun::star::xml::dom::XNode > const & xParent,
+ css::uno::Reference< css::xml::dom::XNode > const & xParent,
OUString const & rTag) const;
/** If there is no child element with a locale matching the office locale, then we use
@@ -239,9 +235,9 @@ private:
However, since OOo 2.4 we use also the first child as default for the license
unless the two attributes are present.
*/
- SAL_DLLPRIVATE ::com::sun::star::uno::Reference< ::com::sun::star::xml::dom::XNode>
+ SAL_DLLPRIVATE css::uno::Reference< css::xml::dom::XNode>
getChildWithDefaultLocale(
- ::com::sun::star::uno::Reference< ::com::sun::star::xml::dom::XNode > const & xParent) const;
+ css::uno::Reference< css::xml::dom::XNode > const & xParent) const;
/**
@param out_bParentExists
indicates if the element node specified in sXPathParent exists.
@@ -266,14 +262,11 @@ private:
*/
SAL_DLLPRIVATE bool
checkBlacklistVersion(const OUString& currentversion,
- ::com::sun::star::uno::Sequence< OUString > const & versions) const;
-
- ::com::sun::star::uno::Reference<
- ::com::sun::star::uno::XComponentContext > m_context;
- ::com::sun::star::uno::Reference<
- ::com::sun::star::xml::dom::XNode > m_element;
- ::com::sun::star::uno::Reference<
- ::com::sun::star::xml::xpath::XXPathAPI > m_xpath;
+ css::uno::Sequence< OUString > const & versions) const;
+
+ css::uno::Reference< css::uno::XComponentContext > m_context;
+ css::uno::Reference< css::xml::dom::XNode > m_element;
+ css::uno::Reference< css::xml::xpath::XXPathAPI > m_xpath;
};
inline bool DescriptionInfoset::hasDescription() const
diff --git a/desktop/source/deployment/inc/dp_identifier.hxx b/desktop/source/deployment/inc/dp_identifier.hxx
index 1da6bd2379db..16d95c57baf9 100644
--- a/desktop/source/deployment/inc/dp_identifier.hxx
+++ b/desktop/source/deployment/inc/dp_identifier.hxx
@@ -60,10 +60,10 @@ DESKTOP_DEPLOYMENTMISC_DLLPUBLIC OUString generateIdentifier(
the explicit identifier of the given package if present, otherwise the
implicit legacy identifier of the given package
- @throws com::sun::star::uno::RuntimeException
+ @throws css::uno::RuntimeException
*/
DESKTOP_DEPLOYMENTMISC_DLLPUBLIC OUString getIdentifier(
- ::com::sun::star::uno::Reference< ::com::sun::star::deployment::XPackage >
+ css::uno::Reference< css::deployment::XPackage >
const & package);
/**
diff --git a/desktop/source/deployment/inc/dp_misc.h b/desktop/source/deployment/inc/dp_misc.h
index 5a548afc9d35..e2d2412c95fb 100644
--- a/desktop/source/deployment/inc/dp_misc.h
+++ b/desktop/source/deployment/inc/dp_misc.h
@@ -48,9 +48,9 @@ protected:
};
-inline void try_dispose( ::com::sun::star::uno::Reference< ::com::sun::star::uno::XInterface> const & x )
+inline void try_dispose( css::uno::Reference< css::uno::XInterface> const & x )
{
- ::com::sun::star::uno::Reference< ::com::sun::star::lang::XComponent> xComp( x, ::com::sun::star::uno::UNO_QUERY );
+ css::uno::Reference< css::lang::XComponent> xComp( x, css::uno::UNO_QUERY );
if (xComp.is())
xComp->dispose();
}
@@ -94,9 +94,9 @@ DESKTOP_DEPLOYMENTMISC_DLLPUBLIC OUString generateRandomPipeId();
class AbortChannel;
DESKTOP_DEPLOYMENTMISC_DLLPUBLIC
-::com::sun::star::uno::Reference< ::com::sun::star::uno::XInterface> resolveUnoURL(
+css::uno::Reference< css::uno::XInterface> resolveUnoURL(
OUString const & connectString,
- ::com::sun::star::uno::Reference< ::com::sun::star::uno::XComponentContext> const & xLocalContext,
+ css::uno::Reference< css::uno::XComponentContext> const & xLocalContext,
AbortChannel * abortChannel = 0 );
@@ -105,7 +105,7 @@ DESKTOP_DEPLOYMENTMISC_DLLPUBLIC bool office_is_running();
DESKTOP_DEPLOYMENTMISC_DLLPUBLIC
oslProcess raiseProcess( OUString const & appURL,
- ::com::sun::star::uno::Sequence< OUString > const & args );
+ css::uno::Sequence< OUString > const & args );
@@ -146,15 +146,15 @@ void TRACE(OUString const & sText);
DESKTOP_DEPLOYMENTMISC_DLLPUBLIC
void syncRepositories(
bool force,
- ::com::sun::star::uno::Reference<
- ::com::sun::star::ucb::XCommandEnvironment> const & xCmdEnv);
+ css::uno::Reference<
+ css::ucb::XCommandEnvironment> const & xCmdEnv);
/** workaround: for some reason the bridge threads which communicate with the
uno.exe process are not released on time
*/
DESKTOP_DEPLOYMENTMISC_DLLPUBLIC
void disposeBridges(
- com::sun::star::uno::Reference< com::sun::star::uno::XComponentContext >
+ css::uno::Reference< css::uno::XComponentContext >
const & ctx);
}
diff --git a/desktop/source/deployment/inc/dp_platform.hxx b/desktop/source/deployment/inc/dp_platform.hxx
index 0331d17396d1..43c7ad8c594f 100644
--- a/desktop/source/deployment/inc/dp_platform.hxx
+++ b/desktop/source/deployment/inc/dp_platform.hxx
@@ -39,7 +39,7 @@ DESKTOP_DEPLOYMENTMISC_DLLPUBLIC
*/
DESKTOP_DEPLOYMENTMISC_DLLPUBLIC
-bool hasValidPlatform( ::com::sun::star::uno::Sequence< OUString > const & platformStrings);
+bool hasValidPlatform( css::uno::Sequence< OUString > const & platformStrings);
}
diff --git a/desktop/source/deployment/inc/dp_update.hxx b/desktop/source/deployment/inc/dp_update.hxx
index e7ceef3a0468..0e07563b59c1 100644
--- a/desktop/source/deployment/inc/dp_update.hxx
+++ b/desktop/source/deployment/inc/dp_update.hxx
@@ -82,21 +82,21 @@ UPDATE_SOURCE isUpdateSharedExtension(
*/
DESKTOP_DEPLOYMENTMISC_DLLPUBLIC
-::com::sun::star::uno::Reference< ::com::sun::star::deployment::XPackage>
+css::uno::Reference< css::deployment::XPackage>
getExtensionWithHighestVersion(
- ::com::sun::star::uno::Sequence<
- ::com::sun::star::uno::Reference<
- ::com::sun::star::deployment::XPackage> > const & seqExtensionsWithSameId);
+ css::uno::Sequence<
+ css::uno::Reference<
+ css::deployment::XPackage> > const & seqExtensionsWithSameId);
struct UpdateInfo
{
- UpdateInfo( ::com::sun::star::uno::Reference< ::com::sun::star::deployment::XPackage> const & ext);
- ::com::sun::star::uno::Reference<
- ::com::sun::star::deployment::XPackage> extension;
-//version of the update
+ UpdateInfo( css::uno::Reference< css::deployment::XPackage> const & ext);
+
+ css::uno::Reference< css::deployment::XPackage> extension;
+ //version of the update
OUString version;
- ::com::sun::star::uno::Reference< ::com::sun::star::xml::dom::XNode > info;
+ css::uno::Reference< css::xml::dom::XNode > info;
};
typedef std::map< OUString, UpdateInfo > UpdateInfoMap;
@@ -118,12 +118,12 @@ typedef std::map< OUString, UpdateInfo > UpdateInfoMap;
*/
DESKTOP_DEPLOYMENTMISC_DLLPUBLIC
UpdateInfoMap getOnlineUpdateInfos(
- ::com::sun::star::uno::Reference< ::com::sun::star::uno::XComponentContext> const &xContext,
- ::com::sun::star::uno::Reference< ::com::sun::star::deployment::XExtensionManager> const & xExtMgr,
- ::com::sun::star::uno::Reference< ::com::sun::star::deployment::XUpdateInformationProvider > const & updateInformation,
- std::vector< ::com::sun::star::uno::Reference< ::com::sun::star::deployment::XPackage > > const * extensionList,
- ::std::vector< ::std::pair< ::com::sun::star::uno::Reference<
- ::com::sun::star::deployment::XPackage>, ::com::sun::star::uno::Any> > & out_errors);
+ css::uno::Reference< css::uno::XComponentContext> const &xContext,
+ css::uno::Reference< css::deployment::XExtensionManager> const & xExtMgr,
+ css::uno::Reference< css::deployment::XUpdateInformationProvider > const & updateInformation,
+ std::vector< css::uno::Reference< css::deployment::XPackage > > const * extensionList,
+ ::std::vector< ::std::pair< css::uno::Reference<
+ css::deployment::XPackage>, css::uno::Any> > & out_errors);
/* retunrs the highest version from the provided arguments.
*/
diff --git a/desktop/source/deployment/manager/dp_activepackages.hxx b/desktop/source/deployment/manager/dp_activepackages.hxx
index a46980de6d90..24449b111382 100644
--- a/desktop/source/deployment/manager/dp_activepackages.hxx
+++ b/desktop/source/deployment/manager/dp_activepackages.hxx
@@ -53,7 +53,7 @@ public:
OUString mediaType;
OUString version;
/* If this string contains the value according to
- com::sun::star::deployment::Prerequisites or "0". That is, if
+ css::deployment::Prerequisites or "0". That is, if
the value is > 0 then
the call to XPackage::checkPrerequisites failed.
In this case the extension must not be registered.
diff --git a/desktop/source/deployment/manager/dp_manager.cxx b/desktop/source/deployment/manager/dp_manager.cxx
index bcb7b90b07a5..73e8b343e522 100644
--- a/desktop/source/deployment/manager/dp_manager.cxx
+++ b/desktop/source/deployment/manager/dp_manager.cxx
@@ -1186,7 +1186,7 @@ void PackageManagerImpl::reinstallDeployedPackages(
sal_Bool SAL_CALL PackageManagerImpl::isReadOnly( )
- throw (::com::sun::star::uno::RuntimeException, std::exception)
+ throw (css::uno::RuntimeException, std::exception)
{
return m_readOnly;
}
diff --git a/desktop/source/deployment/manager/dp_manager.h b/desktop/source/deployment/manager/dp_manager.h
index ee3c0902f923..46e5a262b86c 100644
--- a/desktop/source/deployment/manager/dp_manager.h
+++ b/desktop/source/deployment/manager/dp_manager.h
@@ -235,7 +235,7 @@ public:
css::uno::RuntimeException, std::exception) SAL_OVERRIDE;
virtual ::sal_Bool SAL_CALL isReadOnly( )
- throw (::com::sun::star::uno::RuntimeException, std::exception) SAL_OVERRIDE;
+ throw (css::uno::RuntimeException, std::exception) SAL_OVERRIDE;
virtual ::sal_Bool SAL_CALL synchronize(
css::uno::Reference<css::task::XAbortChannel> const & xAbortChannel,
diff --git a/desktop/source/deployment/registry/configuration/dp_configuration.cxx b/desktop/source/deployment/registry/configuration/dp_configuration.cxx
index f240194d1757..128484a1bd04 100644
--- a/desktop/source/deployment/registry/configuration/dp_configuration.cxx
+++ b/desktop/source/deployment/registry/configuration/dp_configuration.cxx
@@ -722,13 +722,13 @@ void BackendImpl::PackageImpl::processPackage_(
{
if (m_isSchema)
{
- com::sun::star::configuration::Update::get(
+ css::configuration::Update::get(
that->m_xComponentContext)->insertExtensionXcsFile(
that->m_eContext == CONTEXT_SHARED, expandUnoRcUrl(url));
}
else
{
- com::sun::star::configuration::Update::get(
+ css::configuration::Update::get(
that->m_xComponentContext)->insertExtensionXcuFile(
that->m_eContext == CONTEXT_SHARED, expandUnoRcUrl(url));
}
@@ -797,7 +797,7 @@ void BackendImpl::PackageImpl::processPackage_(
//a data entry
if (!m_isSchema && data)
{
- com::sun::star::configuration::Update::get(
+ css::configuration::Update::get(
that->m_xComponentContext)->removeExtensionXcuFile(expandUnoRcTerm(data->iniEntry));
}
that->revokeEntryFromDb(url);
diff --git a/desktop/source/migration/migration.cxx b/desktop/source/migration/migration.cxx
index 53a5e312a9de..ca7fce8d1491 100644
--- a/desktop/source/migration/migration.cxx
+++ b/desktop/source/migration/migration.cxx
@@ -882,7 +882,7 @@ uno::Reference< XNameAccess > MigrationImpl::getConfigAccess(const sal_Char* pPa
theConfigProvider->createInstanceWithArguments(
sAccessSrvc, theArgs ), uno::UNO_QUERY_THROW );
}
- catch (const com::sun::star::uno::Exception& e)
+ catch (const css::uno::Exception& e)
{
SAL_WARN(
"desktop.migration", "ignoring Exception \"" << e.Message << "\"");
diff --git a/desktop/source/migration/services/basicmigration.hxx b/desktop/source/migration/services/basicmigration.hxx
index adec67a75215..de75dab09f99 100644
--- a/desktop/source/migration/services/basicmigration.hxx
+++ b/desktop/source/migration/services/basicmigration.hxx
@@ -39,9 +39,9 @@ namespace migration
OUString SAL_CALL BasicMigration_getImplementationName();
- ::com::sun::star::uno::Sequence< OUString > SAL_CALL BasicMigration_getSupportedServiceNames();
- ::com::sun::star::uno::Reference< ::com::sun::star::uno::XInterface > SAL_CALL BasicMigration_create(
- ::com::sun::star::uno::Reference< ::com::sun::star::uno::XComponentContext > const & xContext );
+ css::uno::Sequence< OUString > SAL_CALL BasicMigration_getSupportedServiceNames();
+ css::uno::Reference< css::uno::XInterface > SAL_CALL BasicMigration_create(
+ css::uno::Reference< css::uno::XComponentContext > const & xContext );
@@ -49,9 +49,9 @@ namespace migration
typedef ::cppu::WeakImplHelper<
- ::com::sun::star::lang::XServiceInfo,
- ::com::sun::star::lang::XInitialization,
- ::com::sun::star::task::XJob > BasicMigration_BASE;
+ css::lang::XServiceInfo,
+ css::lang::XInitialization,
+ css::task::XJob > BasicMigration_BASE;
class BasicMigration : public BasicMigration_BASE
{
@@ -69,21 +69,21 @@ namespace migration
// XServiceInfo
virtual OUString SAL_CALL getImplementationName()
- throw (::com::sun::star::uno::RuntimeException, std::exception) SAL_OVERRIDE;
+ throw (css::uno::RuntimeException, std::exception) SAL_OVERRIDE;
virtual sal_Bool SAL_CALL supportsService( const OUString& rServiceName )
- throw (::com::sun::star::uno::RuntimeException, std::exception) SAL_OVERRIDE;
- virtual ::com::sun::star::uno::Sequence< OUString > SAL_CALL getSupportedServiceNames()
- throw (::com::sun::star::uno::RuntimeException, std::exception) SAL_OVERRIDE;
+ throw (css::uno::RuntimeException, std::exception) SAL_OVERRIDE;
+ virtual css::uno::Sequence< OUString > SAL_CALL getSupportedServiceNames()
+ throw (css::uno::RuntimeException, std::exception) SAL_OVERRIDE;
// XInitialization
- virtual void SAL_CALL initialize( const ::com::sun::star::uno::Sequence< ::com::sun::star::uno::Any >& aArguments )
- throw (::com::sun::star::uno::Exception, ::com::sun::star::uno::RuntimeException, std::exception) SAL_OVERRIDE;
+ virtual void SAL_CALL initialize( const css::uno::Sequence< css::uno::Any >& aArguments )
+ throw (css::uno::Exception, css::uno::RuntimeException, std::exception) SAL_OVERRIDE;
// XJob
- virtual ::com::sun::star::uno::Any SAL_CALL execute(
- const ::com::sun::star::uno::Sequence< ::com::sun::star::beans::NamedValue >& Arguments )
- throw (::com::sun::star::lang::IllegalArgumentException, ::com::sun::star::uno::Exception,
- ::com::sun::star::uno::RuntimeException, std::exception) SAL_OVERRIDE;
+ virtual css::uno::Any SAL_CALL execute(
+ const css::uno::Sequence< css::beans::NamedValue >& Arguments )
+ throw (css::lang::IllegalArgumentException, css::uno::Exception,
+ css::uno::RuntimeException, std::exception) SAL_OVERRIDE;
};
diff --git a/desktop/source/migration/services/jvmfwk.cxx b/desktop/source/migration/services/jvmfwk.cxx
index adee3c883ff8..af75b7d93b2f 100644
--- a/desktop/source/migration/services/jvmfwk.cxx
+++ b/desktop/source/migration/services/jvmfwk.cxx
@@ -105,46 +105,46 @@ public:
// XLayerHandler
virtual void SAL_CALL startLayer()
- throw(::com::sun::star::lang::WrappedTargetException, std::exception) SAL_OVERRIDE;
+ throw(css::lang::WrappedTargetException, std::exception) SAL_OVERRIDE;
virtual void SAL_CALL endLayer()
throw(
- ::com::sun::star::configuration::backend::MalformedDataException,
- ::com::sun::star::lang::WrappedTargetException, std::exception ) SAL_OVERRIDE;
+ css::configuration::backend::MalformedDataException,
+ css::lang::WrappedTargetException, std::exception ) SAL_OVERRIDE;
virtual void SAL_CALL overrideNode(
const OUString& aName,
sal_Int16 aAttributes,
sal_Bool bClear)
throw(
- ::com::sun::star::configuration::backend::MalformedDataException,
- ::com::sun::star::lang::WrappedTargetException, std::exception ) SAL_OVERRIDE;
+ css::configuration::backend::MalformedDataException,
+ css::lang::WrappedTargetException, std::exception ) SAL_OVERRIDE;
virtual void SAL_CALL addOrReplaceNode(
const OUString& aName,
sal_Int16 aAttributes)
throw(
- ::com::sun::star::configuration::backend::MalformedDataException,
- ::com::sun::star::lang::WrappedTargetException, std::exception ) SAL_OVERRIDE;
+ css::configuration::backend::MalformedDataException,
+ css::lang::WrappedTargetException, std::exception ) SAL_OVERRIDE;
virtual void SAL_CALL addOrReplaceNodeFromTemplate(
const OUString& aName,
- const ::com::sun::star::configuration::backend::TemplateIdentifier& aTemplate,
+ const css::configuration::backend::TemplateIdentifier& aTemplate,
sal_Int16 aAttributes )
throw(
- ::com::sun::star::configuration::backend::MalformedDataException,
- ::com::sun::star::lang::WrappedTargetException, std::exception ) SAL_OVERRIDE;
+ css::configuration::backend::MalformedDataException,
+ css::lang::WrappedTargetException, std::exception ) SAL_OVERRIDE;
virtual void SAL_CALL endNode()
throw(
- ::com::sun::star::configuration::backend::MalformedDataException,
- ::com::sun::star::lang::WrappedTargetException, std::exception ) SAL_OVERRIDE;
+ css::configuration::backend::MalformedDataException,
+ css::lang::WrappedTargetException, std::exception ) SAL_OVERRIDE;
virtual void SAL_CALL dropNode(
const OUString& aName )
throw(
- ::com::sun::star::configuration::backend::MalformedDataException,
- ::com::sun::star::lang::WrappedTargetException, std::exception ) SAL_OVERRIDE;
+ css::configuration::backend::MalformedDataException,
+ css::lang::WrappedTargetException, std::exception ) SAL_OVERRIDE;
virtual void SAL_CALL overrideProperty(
const OUString& aName,
@@ -152,42 +152,42 @@ public:
const css::uno::Type& aType,
sal_Bool bClear )
throw(
- ::com::sun::star::configuration::backend::MalformedDataException,
- ::com::sun::star::lang::WrappedTargetException, std::exception ) SAL_OVERRIDE;
+ css::configuration::backend::MalformedDataException,
+ css::lang::WrappedTargetException, std::exception ) SAL_OVERRIDE;
virtual void SAL_CALL setPropertyValue(
const css::uno::Any& aValue )
throw(
- ::com::sun::star::configuration::backend::MalformedDataException,
- ::com::sun::star::lang::WrappedTargetException, std::exception ) SAL_OVERRIDE;
+ css::configuration::backend::MalformedDataException,
+ css::lang::WrappedTargetException, std::exception ) SAL_OVERRIDE;
virtual void SAL_CALL setPropertyValueForLocale(
const css::uno::Any& aValue,
const OUString& aLocale )
throw(
- ::com::sun::star::configuration::backend::MalformedDataException,
- ::com::sun::star::lang::WrappedTargetException, std::exception ) SAL_OVERRIDE;
+ css::configuration::backend::MalformedDataException,
+ css::lang::WrappedTargetException, std::exception ) SAL_OVERRIDE;
virtual void SAL_CALL endProperty()
throw(
- ::com::sun::star::configuration::backend::MalformedDataException,
- ::com::sun::star::lang::WrappedTargetException, std::exception ) SAL_OVERRIDE;
+ css::configuration::backend::MalformedDataException,
+ css::lang::WrappedTargetException, std::exception ) SAL_OVERRIDE;
virtual void SAL_CALL addProperty(
const OUString& aName,
sal_Int16 aAttributes,
const css::uno::Type& aType )
throw(
- ::com::sun::star::configuration::backend::MalformedDataException,
- ::com::sun::star::lang::WrappedTargetException, std::exception ) SAL_OVERRIDE;
+ css::configuration::backend::MalformedDataException,
+ css::lang::WrappedTargetException, std::exception ) SAL_OVERRIDE;
virtual void SAL_CALL addPropertyWithValue(
const OUString& aName,
sal_Int16 aAttributes,
const css::uno::Any& aValue )
throw(
- ::com::sun::star::configuration::backend::MalformedDataException,
- ::com::sun::star::lang::WrappedTargetException, std::exception ) SAL_OVERRIDE;
+ css::configuration::backend::MalformedDataException,
+ css::lang::WrappedTargetException, std::exception ) SAL_OVERRIDE;
diff --git a/desktop/source/migration/services/oo3extensionmigration.hxx b/desktop/source/migration/services/oo3extensionmigration.hxx
index 2d2adc19efda..ad803f89fc0c 100644
--- a/desktop/source/migration/services/oo3extensionmigration.hxx
+++ b/desktop/source/migration/services/oo3extensionmigration.hxx
@@ -47,9 +47,9 @@ namespace migration
{
OUString SAL_CALL OO3ExtensionMigration_getImplementationName();
- ::com::sun::star::uno::Sequence< OUString > SAL_CALL OO3ExtensionMigration_getSupportedServiceNames();
- ::com::sun::star::uno::Reference< ::com::sun::star::uno::XInterface > SAL_CALL OO3ExtensionMigration_create(
- ::com::sun::star::uno::Reference< ::com::sun::star::uno::XComponentContext > const & xContext );
+ css::uno::Sequence< OUString > SAL_CALL OO3ExtensionMigration_getSupportedServiceNames();
+ css::uno::Reference< css::uno::XInterface > SAL_CALL OO3ExtensionMigration_create(
+ css::uno::Reference< css::uno::XComponentContext > const & xContext );
@@ -57,19 +57,19 @@ namespace migration
typedef ::cppu::WeakImplHelper<
- ::com::sun::star::lang::XServiceInfo,
- ::com::sun::star::lang::XInitialization,
- ::com::sun::star::task::XJob > ExtensionMigration_BASE;
+ css::lang::XServiceInfo,
+ css::lang::XInitialization,
+ css::task::XJob > ExtensionMigration_BASE;
class OO3ExtensionMigration : public ExtensionMigration_BASE
{
private:
- ::com::sun::star::uno::Reference< ::com::sun::star::uno::XComponentContext > m_ctx;
- ::com::sun::star::uno::Reference< ::com::sun::star::xml::dom::XDocumentBuilder > m_xDocBuilder;
- ::com::sun::star::uno::Reference< ::com::sun::star::ucb::XSimpleFileAccess3 > m_xSimpleFileAccess;
+ css::uno::Reference< css::uno::XComponentContext > m_ctx;
+ css::uno::Reference< css::xml::dom::XDocumentBuilder > m_xDocBuilder;
+ css::uno::Reference< css::ucb::XSimpleFileAccess3 > m_xSimpleFileAccess;
::osl::Mutex m_aMutex;
- OUString m_sSourceDir;
- OUString m_sTargetDir;
+ OUString m_sSourceDir;
+ OUString m_sTargetDir;
TStringVector m_aBlackList;
enum ScanResult
@@ -86,57 +86,57 @@ namespace migration
void migrateExtension( const OUString& sSourceDir );
public:
- explicit OO3ExtensionMigration(::com::sun::star::uno::Reference<
- ::com::sun::star::uno::XComponentContext > const & ctx);
+ explicit OO3ExtensionMigration(css::uno::Reference<
+ css::uno::XComponentContext > const & ctx);
virtual ~OO3ExtensionMigration();
// XServiceInfo
virtual OUString SAL_CALL getImplementationName()
- throw (::com::sun::star::uno::RuntimeException, std::exception) SAL_OVERRIDE;
+ throw (css::uno::RuntimeException, std::exception) SAL_OVERRIDE;
virtual sal_Bool SAL_CALL supportsService( const OUString& rServiceName )
- throw (::com::sun::star::uno::RuntimeException, std::exception) SAL_OVERRIDE;
- virtual ::com::sun::star::uno::Sequence< OUString > SAL_CALL getSupportedServiceNames()
- throw (::com::sun::star::uno::RuntimeException, std::exception) SAL_OVERRIDE;
+ throw (css::uno::RuntimeException, std::exception) SAL_OVERRIDE;
+ virtual css::uno::Sequence< OUString > SAL_CALL getSupportedServiceNames()
+ throw (css::uno::RuntimeException, std::exception) SAL_OVERRIDE;
// XInitialization
- virtual void SAL_CALL initialize( const ::com::sun::star::uno::Sequence< ::com::sun::star::uno::Any >& aArguments )
- throw (::com::sun::star::uno::Exception, ::com::sun::star::uno::RuntimeException, std::exception) SAL_OVERRIDE;
+ virtual void SAL_CALL initialize( const css::uno::Sequence< css::uno::Any >& aArguments )
+ throw (css::uno::Exception, css::uno::RuntimeException, std::exception) SAL_OVERRIDE;
// XJob
- virtual ::com::sun::star::uno::Any SAL_CALL execute(
- const ::com::sun::star::uno::Sequence< ::com::sun::star::beans::NamedValue >& Arguments )
- throw (::com::sun::star::lang::IllegalArgumentException, ::com::sun::star::uno::Exception,
- ::com::sun::star::uno::RuntimeException, std::exception) SAL_OVERRIDE;
+ virtual css::uno::Any SAL_CALL execute(
+ const css::uno::Sequence< css::beans::NamedValue >& Arguments )
+ throw (css::lang::IllegalArgumentException, css::uno::Exception,
+ css::uno::RuntimeException, std::exception) SAL_OVERRIDE;
};
class TmpRepositoryCommandEnv
- : public ::cppu::WeakImplHelper< ::com::sun::star::ucb::XCommandEnvironment,
- ::com::sun::star::task::XInteractionHandler,
- ::com::sun::star::ucb::XProgressHandler >
+ : public ::cppu::WeakImplHelper< css::ucb::XCommandEnvironment,
+ css::task::XInteractionHandler,
+ css::ucb::XProgressHandler >
{
- ::com::sun::star::uno::Reference< ::com::sun::star::uno::XComponentContext > m_xContext;
- ::com::sun::star::uno::Reference< ::com::sun::star::task::XInteractionHandler> m_forwardHandler;
+ css::uno::Reference< css::uno::XComponentContext > m_xContext;
+ css::uno::Reference< css::task::XInteractionHandler> m_forwardHandler;
public:
virtual ~TmpRepositoryCommandEnv();
TmpRepositoryCommandEnv();
// XCommandEnvironment
- virtual ::com::sun::star::uno::Reference< ::com::sun::star::task::XInteractionHandler > SAL_CALL
- getInteractionHandler() throw ( ::com::sun::star::uno::RuntimeException, std::exception ) SAL_OVERRIDE;
- virtual ::com::sun::star::uno::Reference< ::com::sun::star::ucb::XProgressHandler >
- SAL_CALL getProgressHandler() throw ( ::com::sun::star::uno::RuntimeException, std::exception ) SAL_OVERRIDE;
+ virtual css::uno::Reference< css::task::XInteractionHandler > SAL_CALL
+ getInteractionHandler() throw ( css::uno::RuntimeException, std::exception ) SAL_OVERRIDE;
+ virtual css::uno::Reference< css::ucb::XProgressHandler >
+ SAL_CALL getProgressHandler() throw ( css::uno::RuntimeException, std::exception ) SAL_OVERRIDE;
// XInteractionHandler
virtual void SAL_CALL handle(
- ::com::sun::star::uno::Reference< ::com::sun::star::task::XInteractionRequest > const & xRequest )
- throw (::com::sun::star::uno::RuntimeException, std::exception) SAL_OVERRIDE;
+ css::uno::Reference< css::task::XInteractionRequest > const & xRequest )
+ throw (css::uno::RuntimeException, std::exception) SAL_OVERRIDE;
// XProgressHandler
- virtual void SAL_CALL push( ::com::sun::star::uno::Any const & Status )
- throw (::com::sun::star::uno::RuntimeException, std::exception) SAL_OVERRIDE;
- virtual void SAL_CALL update( ::com::sun::star::uno::Any const & Status )
- throw (::com::sun::star::uno::RuntimeException, std::exception) SAL_OVERRIDE;
- virtual void SAL_CALL pop() throw (::com::sun::star::uno::RuntimeException, std::exception) SAL_OVERRIDE;
+ virtual void SAL_CALL push( css::uno::Any const & Status )
+ throw (css::uno::RuntimeException, std::exception) SAL_OVERRIDE;
+ virtual void SAL_CALL update( css::uno::Any const & Status )
+ throw (css::uno::RuntimeException, std::exception) SAL_OVERRIDE;
+ virtual void SAL_CALL pop() throw (css::uno::RuntimeException, std::exception) SAL_OVERRIDE;
};
diff --git a/desktop/source/migration/services/wordbookmigration.hxx b/desktop/source/migration/services/wordbookmigration.hxx
index 435221408faf..a943d62091c6 100644
--- a/desktop/source/migration/services/wordbookmigration.hxx
+++ b/desktop/source/migration/services/wordbookmigration.hxx
@@ -39,9 +39,9 @@ namespace migration
OUString SAL_CALL WordbookMigration_getImplementationName();
- ::com::sun::star::uno::Sequence< OUString > SAL_CALL WordbookMigration_getSupportedServiceNames();
- ::com::sun::star::uno::Reference< ::com::sun::star::uno::XInterface > SAL_CALL WordbookMigration_create(
- ::com::sun::star::uno::Reference< ::com::sun::star::uno::XComponentContext > const & xContext );
+ css::uno::Sequence< OUString > SAL_CALL WordbookMigration_getSupportedServiceNames();
+ css::uno::Reference< css::uno::XInterface > SAL_CALL WordbookMigration_create(
+ css::uno::Reference< css::uno::XComponentContext > const & xContext );
@@ -49,9 +49,9 @@ namespace migration
typedef ::cppu::WeakImplHelper<
- ::com::sun::star::lang::XServiceInfo,
- ::com::sun::star::lang::XInitialization,
- ::com::sun::star::task::XJob > WordbookMigration_BASE;
+ css::lang::XServiceInfo,
+ css::lang::XInitialization,
+ css::task::XJob > WordbookMigration_BASE;
class WordbookMigration : public WordbookMigration_BASE
{
@@ -69,21 +69,21 @@ namespace migration
// XServiceInfo
virtual OUString SAL_CALL getImplementationName()
- throw (::com::sun::star::uno::RuntimeException, std::exception) SAL_OVERRIDE;
+ throw (css::uno::RuntimeException, std::exception) SAL_OVERRIDE;
virtual sal_Bool SAL_CALL supportsService( const OUString& rServiceName )
- throw (::com::sun::star::uno::RuntimeException, std::exception) SAL_OVERRIDE;
- virtual ::com::sun::star::uno::Sequence< OUString > SAL_CALL getSupportedServiceNames()
- throw (::com::sun::star::uno::RuntimeException, std::exception) SAL_OVERRIDE;
+ throw (css::uno::RuntimeException, std::exception) SAL_OVERRIDE;
+ virtual css::uno::Sequence< OUString > SAL_CALL getSupportedServiceNames()
+ throw (css::uno::RuntimeException, std::exception) SAL_OVERRIDE;
// XInitialization
- virtual void SAL_CALL initialize( const ::com::sun::star::uno::Sequence< ::com::sun::star::uno::Any >& aArguments )
- throw (::com::sun::star::uno::Exception, ::com::sun::star::uno::RuntimeException, std::exception) SAL_OVERRIDE;
+ virtual void SAL_CALL initialize( const css::uno::Sequence< css::uno::Any >& aArguments )
+ throw (css::uno::Exception, css::uno::RuntimeException, std::exception) SAL_OVERRIDE;
// XJob
- virtual ::com::sun::star::uno::Any SAL_CALL execute(
- const ::com::sun::star::uno::Sequence< ::com::sun::star::beans::NamedValue >& Arguments )
- throw (::com::sun::star::lang::IllegalArgumentException, ::com::sun::star::uno::Exception,
- ::com::sun::star::uno::RuntimeException, std::exception) SAL_OVERRIDE;
+ virtual css::uno::Any SAL_CALL execute(
+ const css::uno::Sequence< css::beans::NamedValue >& Arguments )
+ throw (css::lang::IllegalArgumentException, css::uno::Exception,
+ css::uno::RuntimeException, std::exception) SAL_OVERRIDE;
};
diff --git a/desktop/source/offacc/acceptor.hxx b/desktop/source/offacc/acceptor.hxx
index e91ef02c55fe..dd1df6e5e045 100644
--- a/desktop/source/offacc/acceptor.hxx
+++ b/desktop/source/offacc/acceptor.hxx
@@ -54,7 +54,7 @@ private:
osl::Mutex m_aMutex;
oslThread m_thread;
- comphelper::WeakBag< com::sun::star::bridge::XBridge > m_bridges;
+ comphelper::WeakBag< css::bridge::XBridge > m_bridges;
::osl::Condition m_cEnable;
diff --git a/desktop/source/pkgchk/unopkg/unopkg_app.cxx b/desktop/source/pkgchk/unopkg/unopkg_app.cxx
index 03d966761f1f..a76d95038bf8 100644
--- a/desktop/source/pkgchk/unopkg/unopkg_app.cxx
+++ b/desktop/source/pkgchk/unopkg/unopkg_app.cxx
@@ -350,7 +350,7 @@ extern "C" int unopkg_main()
Reference<deployment::XExtensionManager> xExtensionManager(
deployment::ExtensionManager::get( xComponentContext ) );
- Reference< ::com::sun::star::ucb::XCommandEnvironment > xCmdEnv(
+ Reference< css::ucb::XCommandEnvironment > xCmdEnv(
createCmdEnv( xComponentContext, logFile,
option_force, option_verbose, option_suppressLicense) );
@@ -597,7 +597,7 @@ extern "C" int unopkg_main()
dp_misc::writeConsoleError(e.Message + "\n");
bNoOtherErrorMsg = true;
}
- catch (const ::com::sun::star::uno::Exception & e ) {
+ catch (const css::uno::Exception & e ) {
Any exc( ::cppu::getCaughtException() );
dp_misc::writeConsoleError("\nERROR: " +
diff --git a/desktop/source/splash/splash.cxx b/desktop/source/splash/splash.cxx
index 6b64d25df25c..17f07dd621be 100644
--- a/desktop/source/splash/splash.cxx
+++ b/desktop/source/splash/splash.cxx
@@ -115,7 +115,7 @@ public:
virtual void SAL_CALL start(const OUString& aText, sal_Int32 nRange) throw ( RuntimeException, std::exception ) SAL_OVERRIDE;
// XInitialize
- virtual void SAL_CALL initialize( const ::com::sun::star::uno::Sequence< ::com::sun::star::uno::Any>& aArguments )
+ virtual void SAL_CALL initialize( const css::uno::Sequence< css::uno::Any>& aArguments )
throw ( RuntimeException, std::exception ) SAL_OVERRIDE;
virtual OUString SAL_CALL getImplementationName()
@@ -273,7 +273,7 @@ void SAL_CALL SplashScreen::setValue(sal_Int32 nValue)
// XInitialize
void SAL_CALL
-SplashScreen::initialize( const ::com::sun::star::uno::Sequence< ::com::sun::star::uno::Any>& aArguments )
+SplashScreen::initialize( const css::uno::Sequence< css::uno::Any>& aArguments )
throw (RuntimeException, std::exception)
{
::osl::ClearableMutexGuard aGuard( _aMutex );
diff --git a/desktop/source/splash/splash.hxx b/desktop/source/splash/splash.hxx
index 044177284cc7..813e17248a12 100644
--- a/desktop/source/splash/splash.hxx
+++ b/desktop/source/splash/splash.hxx
@@ -35,14 +35,12 @@ namespace com { namespace sun { namespace star {
namespace desktop { namespace splash {
-com::sun::star::uno::Reference< com::sun::star::uno::XInterface > SAL_CALL
-create(
- com::sun::star::uno::Reference< com::sun::star::uno::XComponentContext >
- const &);
+css::uno::Reference< css::uno::XInterface > SAL_CALL
+create( css::uno::Reference< css::uno::XComponentContext > const & );
OUString SAL_CALL getImplementationName();
-com::sun::star::uno::Sequence< OUString > SAL_CALL
+css::uno::Sequence< OUString > SAL_CALL
getSupportedServiceNames();
} }
diff --git a/desktop/source/splash/unxsplash.cxx b/desktop/source/splash/unxsplash.cxx
index 6e4fe71ace0a..cc7ecc50cb35 100644
--- a/desktop/source/splash/unxsplash.cxx
+++ b/desktop/source/splash/unxsplash.cxx
@@ -95,7 +95,7 @@ void SAL_CALL UnxSplashScreen::setValue( sal_Int32 nValue )
// XInitialize
void SAL_CALL
-UnxSplashScreen::initialize( const ::com::sun::star::uno::Sequence< ::com::sun::star::uno::Any>& )
+UnxSplashScreen::initialize( const css::uno::Sequence< css::uno::Any>& )
throw ( RuntimeException, std::exception )
{
for ( sal_uInt32 i = 0; i < osl_getCommandArgCount(); i++ )
diff --git a/desktop/source/splash/unxsplash.hxx b/desktop/source/splash/unxsplash.hxx
index e0f7a189c4cd..8a5294d5eabe 100644
--- a/desktop/source/splash/unxsplash.hxx
+++ b/desktop/source/splash/unxsplash.hxx
@@ -74,7 +74,7 @@ public:
uno::Reference< uno::XInterface > SAL_CALL UnxSplash_createInstance(const uno::Reference< uno::XComponentContext > & xCtx ) throw( uno::Exception );
OUString UnxSplash_getImplementationName();
-com::sun::star::uno::Sequence< OUString > SAL_CALL UnxSplash_getSupportedServiceNames() throw ();
+css::uno::Sequence< OUString > SAL_CALL UnxSplash_getSupportedServiceNames() throw ();
#endif // INCLUDED_DESKTOP_SOURCE_SPLASH_UNXSPLASH_HXX
diff --git a/desktop/test/deployment/update/updateinfocreation/build/TestExtension.idl b/desktop/test/deployment/update/updateinfocreation/build/TestExtension.idl
index e304792e9cd4..87b2540e44e9 100644
--- a/desktop/test/deployment/update/updateinfocreation/build/TestExtension.idl
+++ b/desktop/test/deployment/update/updateinfocreation/build/TestExtension.idl
@@ -26,7 +26,7 @@
module com { module sun { module star { module comp { module smoketest {
// example service, XServiceInfo is implemented here for demonstration
// issues. XServiceInfo must be implemented by all components.
- service TestExtension: ::com::sun::star::lang::XServiceInfo;
+ service TestExtension: css::lang::XServiceInfo;
};};};};};
#endif
diff --git a/desktop/source/deployment/gui/dp_gui_extlistbox.hxx b/desktop/source/deployment/gui/dp_gui_extlistbox.hxx
index befa6d0a58e0..f18cf82d3bde 100644
--- a/desktop/source/deployment/gui/dp_gui_extlistbox.hxx
+++ b/desktop/source/deployment/gui/dp_gui_extlistbox.hxx
@@ -144,12 +144,12 @@ class ExtensionBox_Impl : public ::svt::IExtensionListBox
std::vector< TEntry_Impl > m_vEntries;
std::vector< TEntry_Impl > m_vRemovedEntries;
- ::com::sun::star::lang::Locale *m_pLocale;
- CollatorWrapper *m_pCollator;
+ css::lang::Locale *m_pLocale;
+ CollatorWrapper *m_pCollator;
//Holds weak references to extensions to which is we have added an XEventListener
- std::vector< ::com::sun::star::uno::WeakReference<
- ::com::sun::star::deployment::XPackage> > m_vListenerAdded;
+ std::vector< css::uno::WeakReference<
+ css::deployment::XPackage> > m_vListenerAdded;
//Removes the dead weak references from m_vListenerAdded
void cleanVecListenerAdded();
void addEventListenerOnce(css::uno::Reference<css::deployment::XPackage> const & extension);
@@ -166,7 +166,7 @@ class ExtensionBox_Impl : public ::svt::IExtensionListBox
DECL_DLLPRIVATE_LINK_TYPED( ScrollHdl, ScrollBar*, void );
//Index starts with 1.
//Throws an com::sun::star::lang::IllegalArgumentException, when the index is invalid.
void checkIndex(sal_Int32 pos) const;
@@ -218,32 +218,32 @@ public:
/** @return The item name of the entry with the given index
The index starts with 0.
- Throws an com::sun::star::lang::IllegalArgumentException, when the position is invalid. */
+ Throws an css::lang::IllegalArgumentException, when the position is invalid. */
virtual OUString getItemName( sal_Int32 index ) const SAL_OVERRIDE;
/** @return The version string of the entry with the given index
The index starts with 0.
- Throws an com::sun::star::lang::IllegalArgumentException, when the position is invalid. */
+ Throws an css::lang::IllegalArgumentException, when the position is invalid. */
virtual OUString getItemVersion( sal_Int32 index ) const SAL_OVERRIDE;
/** @return The description string of the entry with the given index
The index starts with 0.
- Throws an com::sun::star::lang::IllegalArgumentException, when the position is invalid. */
+ Throws an css::lang::IllegalArgumentException, when the position is invalid. */
virtual OUString getItemDescription( sal_Int32 index ) const SAL_OVERRIDE;
/** @return The publisher string of the entry with the given index
The index starts with 0.
- Throws an com::sun::star::lang::IllegalArgumentException, when the position is invalid. */
+ Throws an css::lang::IllegalArgumentException, when the position is invalid. */
virtual OUString getItemPublisher( sal_Int32 index ) const SAL_OVERRIDE;
/** @return The link behind the publisher text of the entry with the given index
The index starts with 0.
- Throws an com::sun::star::lang::IllegalArgumentException, when the position is invalid. */
+ Throws an css::lang::IllegalArgumentException, when the position is invalid. */
virtual OUString getItemPublisherLink( sal_Int32 index ) const SAL_OVERRIDE;
/** The entry at the given position will be selected
Index starts with 0.
- Throws an com::sun::star::lang::IllegalArgumentException, when the position is invalid. */
+ Throws an css::lang::IllegalArgumentException, when the position is invalid. */
virtual void select( sal_Int32 pos ) SAL_OVERRIDE;
/** The first found entry with the given name will be selected
@@ -166,7 +166,7 @@ class ExtensionBox_Impl : public ::svt::IExtensionListBox
DECL_DLLPRIVATE_LINK_TYPED( ScrollHdl, ScrollBar*, void );
//Index starts with 1.
- //Throws an com::sun::star::lang::IllegalArgumentException, when the index is invalid.
+ //Throws an css::lang::IllegalArgumentException, when the index is invalid.
void checkIndex(sal_Int32 pos) const;
diff --git a/desktop/source/deployment/misc/dp_descriptioninfoset.cxx b/desktop/source/deployment/misc/dp_descriptioninfoset.cxx
index 68f2d4a05b27..8ba5b0aeab9c 100644
--- a/desktop/source/deployment/misc/dp_descriptioninfoset.cxx
+++ b/desktop/source/deployment/misc/dp_descriptioninfoset.cxx
@@ -113,8 +113,8 @@ public:
or any other error occurred. Therefore it should only be used with
new extensions.
- Throws com::sun::star::uno::RuntimeException,
- com::sun::star::deployment::DeploymentException,
+ Throws css::uno::RuntimeException,
+ css::deployment::DeploymentException,
dp_registry::backend::bundle::NoDescriptionException.
*/
ExtensionDescription(
@@ -169,7 +169,7 @@ ExtensionDescription::ExtensionDescription(
const Reference< css::ucb::XCommandEnvironment >& xCmdEnv)
{
try {
- //may throw ::com::sun::star::ucb::ContentCreationException
+ //may throw css::ucb::ContentCreationException
//If there is no description.xml then ucb will start an interaction which
//brings up a dialog.We want to prevent this. Therefore we wrap the xCmdEnv
//and filter the respective exception out.
@@ -179,7 +179,7 @@ ExtensionDescription::ExtensionDescription(
new FileDoesNotExistFilter(xCmdEnv));
::ucbhelper::Content descContent(sDescriptionUri, xFilter, xContext);
//throws an com::sun::star::uno::Exception if the file is not available
Reference<css::io::XInputStream> xIn;
try
{ //throws com.sun.star.ucb.InteractiveIOException
@@ -448,7 +448,7 @@ void DescriptionInfoset::checkBlacklist() const
bool DescriptionInfoset::checkBlacklistVersion(
const OUString& currentversion,
- ::com::sun::star::uno::Sequence< OUString > const & versions) const
+ css::uno::Sequence< OUString > const & versions) const
{
sal_Int32 nLen = versions.getLength();
for (sal_Int32 i=0; i<nLen; i++) {
@@ -179,7 +179,7 @@ ExtensionDescription::ExtensionDescription(
new FileDoesNotExistFilter(xCmdEnv));
::ucbhelper::Content descContent(sDescriptionUri, xFilter, xContext);
- //throws an com::sun::star::uno::Exception if the file is not available
+ //throws an css::uno::Exception if the file is not available
Reference<css::io::XInputStream> xIn;
try